jQuery(function($) {
    function alertLeavePage(e) {
        var dialogText = "Are you sure you want to leave?";
        e.returnValue = dialogText;
        return dialogText;
    }

    function addAlertLeavePage() {
        $('.jms-install-demos .button-install-demo').attr('disabled', 'disabled');
        $(window).bind('beforeunload', alertLeavePage);
    }

    function removeAlertLeavePage() {
        $('.jms-install-demos .button-install-demo').removeAttr('disabled');
        $(window).unbind('beforeunload', alertLeavePage);
        setTimeout(function() {
            $('.jms-install-demos #import-status').slideUp().html('');
        }, 3000);
    }

    function showImportMessage(selected_demo, message, count, index) {
        html = '';
        if (selected_demo) {
            html += '<h3>Installing ' + $('#' + selected_demo).html() + '</h3>';
        }
        if (message) {
            html += '<strong>' + message + '</strong>';
        }
        if (count && index) {
            percent = index / count * 100;
            if (percent > 100)
                percent = 100;
            html += '<div class="import-progress-bar"><div style="width:' + percent + '%;"></div></div>';
        }
        $('.jms-install-demos #import-status').stop().show().html(html);
    }


    // install demo
    $( '.button-install-demo' ).on( 'click', function(e) {
        e.preventDefault();
        var $this = $(this),
            selected_demo = $this.data( 'demo-id' ),
            disabled = $this.attr('disabled');

        if (disabled)
            return;

        addAlertLeavePage();

        $('#jms-install-demo-type').val(selected_demo);
        $('#jms-install-options .theme-name').html($this.closest('.theme-wrapper').find('.theme-name').html());
        $('#jms-install-options').slideDown();

        $('html, body').stop().animate({
            scrollTop: $('#jms-install-options').offset().top - 50
        }, 600);

    });

    // cancel import button
    $('#jms-import-no').click(function() {
        $('#jms-install-options').slideUp();
        removeAlertLeavePage();
    });

    // import
    $('#jms-import-yes').click(function() {
        var demo = $('#jms-install-demo-type').val(),
            options = {
                demo: demo,
                reset_menus: $('#jms-reset-menus').is(':checked'),
                reset_widgets: $('#jms-reset-widgets').is(':checked'),
                import_dummy: $('#jms-import-dummy').is(':checked'),
                import_shortcodes: $('#jms-import-shortcodes').is(':checked'),
                import_widgets: $('#jms-import-widgets').is(':checked'),
                import_sliders: $('#jms-import-sliders').is(':checked'),
                import_options: $('#jms-import-options').is(':checked')
            };

        if (options.demo) {
            showImportMessage(demo, '');
            jms_import_options(options);
        }
        $('#jms-install-options').slideUp();
    });

    // import options
    function jms_import_options(options) {
        if (!options.demo) {
            removeAlertLeavePage();
            return;
        }
        if (options.import_options) {
            var demo = options.demo,
                data = {'action': 'jms_import_options', 'demo': demo};

            showImportMessage(demo, 'Importing theme options');

            $.post(ajaxurl, data, function(response) {
                if (response) showImportMessage(demo, response);
                jms_reset_menus(options);
            }).fail(function(response) {
                    jms_reset_menus(options);
                });
        } else {
            jms_reset_menus(options);
        }
    }

    // reset_menus
    function jms_reset_menus(options) {
        if (!options.demo) {
            removeAlertLeavePage();
            return;
        }
        if (options.reset_menus) {
            var demo = options.demo,
                data = {'action': 'jms_reset_menus', 'import_shortcodes': options.import_shortcodes};

            $.post(ajaxurl, data, function(response) {
                if (response) showImportMessage(demo, response);
                jms_reset_widgets(options);
            }).fail(function(response) {
                jms_reset_widgets(options);
            });
        } else {
            jms_reset_widgets(options);
        }
    }

    // reset widgets
    function jms_reset_widgets(options) {
        if (!options.demo) {
            removeAlertLeavePage();
            return;
        }
        if (options.reset_widgets) {
            var demo = options.demo,
                data = {'action': 'jms_reset_widgets'};

            $.post(ajaxurl, data, function(response) {
                if (response) showImportMessage(demo, response);
                jms_import_dummy(options);
            }).fail(function(response) {
                jms_import_dummy(options);
            });
        } else {
            jms_import_dummy(options);
        }
    }

    // import dummy content
    var dummy_index = 0, dummy_count = 0, dummy_process = 'import_start';
    function jms_import_dummy(options) {
        if (!options.demo) {
            removeAlertLeavePage();
            return;
        }
        if (options.import_dummy) {
            var demo = options.demo,
                data = {'action': 'jms_import_dummy', 'process':'import_start', 'demo': demo};

            dummy_index = 0;
            dummy_count = 0;
            dummy_process = 'import_start';
            jms_import_dummy_process(options, data);
        } else {
			jms_import_widgets(options);
		}
    }

    // import dummy content process
    function jms_import_dummy_process(options, args) {
        var demo = options.demo;

        $.post(ajaxurl, args, function(response) {
            if (response && /^[\],:{}\s]*$/.test(response.replace(/\\["\\\/bfnrtu]/g, '@').
                replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']').
                replace(/(?:^|:|,)(?:\s*\[)+/g, ''))) {
                response = $.parseJSON(response);

                if (response.process != 'complete') {
                    var requests = {'action': 'jms_import_dummy'};
                    if (response.process) requests.process = response.process;
                    if (response.index) requests.index = response.index;
					//alert(response.process);
                    requests.demo = demo;
                    jms_import_dummy_process(options, requests);

                    dummy_index = response.index;
                    dummy_count = response.count;
                    dummy_process = response.process;

                    showImportMessage(demo, response.message, dummy_count, dummy_index);
                } else {
                    showImportMessage(demo, response.message);
                    jms_import_widgets(options);
                }
            } else {
                showImportMessage(demo, 'Failed importing! Please check the "System Status" tab to ensure your server meets all requirements for a successful import. Settings that need attention will be listed in red.');
            }
        }).fail(function(response) {
            if (dummy_index < dummy_count) {
                var requests = {'action': 'jms_import_dummy'};
                requests.process = dummy_process;
                requests.index = ++dummy_index;
                requests.demo = demo;

                jms_import_dummy_process(options, requests);
            } else {
                var requests = {'action': 'jms_import_dummy'};
                requests.process = dummy_process;
                requests.demo = demo;

                jms_import_dummy_process(options, requests);
            }
        });
    }
	// import widgets
    function jms_import_widgets(options) {
        if (!options.demo) {
            removeAlertLeavePage();
            return;
        }
        if (options.import_widgets) {
            var demo = options.demo,
                data = {'action': 'jms_import_widgets', 'demo': demo};

            showImportMessage(demo, 'Importing widgets');

            $.post(ajaxurl, data, function(response) {
                if (response) showImportMessage(demo, response);
                jms_import_sliders(options);
            }).fail(function(response) {
                jms_import_sliders(options);
            });
        } else {
            jms_import_sliders(options);
        }
    }
	// import widgets
    function jms_import_sliders(options) {
        if (!options.demo) {
            removeAlertLeavePage();
            return;
        }
        if (options.import_sliders) {
            var demo = options.demo,
                data = {'action': 'jms_import_sliders', 'demo': demo};

            showImportMessage(demo, 'Importing Sliders');

            $.post(ajaxurl, data, function(response) {
                if (response) showImportMessage(demo, response);
                jms_import_finished(options);
            }).fail(function(response) {
                jms_import_finished(options);
            });
        } else {
            jms_import_finished(options);
        }
    }
    // import finished
    function jms_import_finished(options) {
        if (!options.demo) {
            removeAlertLeavePage();
            return;
        }
        var demo = options.demo;
        setTimeout(function() {
            showImportMessage(demo, 'Finished! Please visit your site.');
            setTimeout(removeAlertLeavePage, 3000);
        }, 3000);
    }
});
