<?php
class JMS_FullData_Importer {
	private $filename;
	public $tables = array();

	/**
	 * Construct function.
	 *
	 * @return  void
	 */
	public function __construct() {
		$this->filename = 'fulldata.json';
		$this->tables = array( 'options','postmeta','posts','terms','term_relationships','term_taxonomy','woocommerce_attribute_taxonomies','woocommerce_termmeta','jms_sliders','jms_slider_slides' );

		add_action( 'wp_ajax_fulldata_import', array( $this,'import' ) );
		add_action( 'wp_ajax_nopriv_fulldata_import', array( $this,'import' ) );
	}

	public function getDataFilePath() {
		return get_template_directory() . '/inc/admin/data/' . $this->filename;
	}

	/**
	 * Import database.
	 *
	 * @return  void
	 */
	public function import() {
		global $wpdb, $table_prefix;

		global $wp_filesystem;
	   	if (empty($wp_filesystem)) {
	    	require_once (ABSPATH . '/wp-admin/includes/file.php');
	    	WP_Filesystem();
	   	}

		$view = $_REQUEST['layout'];
		if ( ! defined( 'WP_LOAD_IMPORTERS' ) ) define( 'WP_LOAD_IMPORTERS', true );

		require_once ABSPATH . 'wp-admin/includes/import.php';

		if ( ! class_exists( 'WP_Importer' ) ) {
			$class_wp_importer = ABSPATH . 'wp-admin/includes/class-wp-importer.php';

			if ( file_exists( $class_wp_importer ) ) {
				require_once( $class_wp_importer );
			}
		}

		if ( ! class_exists( 'JMS_WP_Import' ) ) {
			$class_wp_import = get_template_directory() . '/inc/admin/jms-wordpress-importer.php';

			if ( file_exists( $class_wp_import ) )
				require_once($class_wp_import);
			else
				$importer_error = true;
		}

		$content = $wp_filesystem->get_contents( get_template_directory() . '/inc/admin/data/'. $this->filename );
		$data = ( array )json_decode( $content );

		foreach( $data as $key => $value ) {
			$table = $table_prefix.$key;
			$rows = $value;
			if ( $key == 'options' ) {
				$wpdb->get_results( 'DELETE FROM ' . $table . ' WHERE option_name NOT IN ("siteurl","fileupload_url","home","' . $table_prefix . 'user_roles")' );
			} else {
				$wpdb->get_results( 'TRUNCATE TABLE ' . $table );
			}
			foreach( $rows as $row ) {
				$row = ( array )$row;
				if ( $key == 'options' ) {
					if ( $row['option_name'] != 'wp_user_roles' && $row['option_name'] != 'siteurl' && $row['option_name'] != 'fileupload_url' && $row['option_name'] != 'home' ) {
						$wpdb->insert($table,$row);
					}
				} else {
					$wpdb->insert( $table, $row );
				}
			}
		}

		$args = array(
			'post_type'      => 'attachment',
			'order'          => 'ASC',
			'posts_per_page' => 1000
		);

		$to_url = get_site_url();
		$urls   = array( 'http://localhost/wp/jms_fluent' );
		foreach( $urls as $from_url ) {
			$wpdb->query( $wpdb->prepare( "UPDATE {$wpdb->postmeta} SET meta_value = REPLACE(meta_value, %s, %s) WHERE meta_key='_menu_item_url'", $from_url, $to_url ) );
		}

		$posts = get_posts( $args );
		$wp_import = new JMS_WP_Import();
		foreach ( $posts as $post ) {
			$post = ( array )$post;
			$post['upload_date'] = date( 'Y-m-d' );
			$url = FLUENT_URL . '/inc/admin/data/img.png';
			$upload = $wp_import->fetch_remote_file( $url, ( array )$post );
			if ( is_array( $upload ) ) {
				update_attached_file( $post['ID'], $upload['file'] );
				wp_update_attachment_metadata( $post['ID'], wp_generate_attachment_metadata( $post['ID'], $upload['file'] ) );
			}
		}
		wp_reset_postdata();
	}

}
