<?php

defined( 'ABSPATH' ) or die( 'You cannot access this script directly' );

// add import ajax actions
add_action( 'wp_ajax_jms_reset_menus', 'jms_reset_menus' );
add_action( 'wp_ajax_jms_reset_widgets', 'jms_reset_widgets' );
add_action( 'wp_ajax_jms_import_dummy', 'jms_import_dummy' );
add_action( 'wp_ajax_jms_import_widgets', 'jms_import_widgets' );
add_action( 'wp_ajax_jms_import_options', 'jms_import_options' );
add_action( 'wp_ajax_jms_import_sliders', 'jms_import_sliders' );

function jms_reset_menus() {
    if ( current_user_can( 'manage_options' ) ) {
        $menus = array('Header Menu', 'Footer Menu', 'Header Menu - Bottom', 'Top Menu', 'Collection', 'Extra', 'Information', 'My Account');
        foreach ($menus as $menu) {
            wp_delete_nav_menu($menu);
        }
        echo __('Successfully reset menus!', 'fluent');
    }
    die;
}

function jms_reset_widgets() {
    if ( current_user_can( 'manage_options' ) ) {
        ob_start();
        $sidebars_widgets = retrieve_widgets();
        foreach ($sidebars_widgets as $area => $widgets) {
            foreach ( $widgets as $key => $widget_id ) {
                $pieces = explode( '-', $widget_id );
                $multi_number = array_pop( $pieces );
                $id_base = implode( '-', $pieces );
                $widget = get_option( 'widget_' . $id_base );
                unset( $widget[$multi_number] );
                update_option( 'widget_' . $id_base, $widget );
                unset( $sidebars_widgets[$area][$key] );
            }
        }
        wp_set_sidebars_widgets( $sidebars_widgets );
        ob_clean();
        ob_end_clean();
        echo __('Successfully reset widgets!', 'fluent');
    }
    die;
}

function jms_import_dummy() {
	
    if ( !defined('WP_LOAD_IMPORTERS') ) define('WP_LOAD_IMPORTERS', true); // we are loading importers

    if ( ! class_exists( 'WP_Importer' ) ) { // if main importer class doesn't exist
        $wp_importer = ABSPATH . 'wp-admin/includes/class-wp-importer.php';
        include $wp_importer;
    }
	
    if ( ! class_exists('JMS_WP_Import') ) { // if WP importer doesn't exist
        $wp_import = get_template_directory() . '/inc/admin/jms-wordpress-importer.php';
        include $wp_import;
    }
	
    if ( current_user_can( 'manage_options' ) && class_exists( 'WP_Importer' ) && class_exists( 'JMS_WP_Import' ) ) { // check for main import class and wp import class
		
        $process = (isset($_POST['process']) && $_POST['process']) ? $_POST['process'] : 'import_start';
        $demo = (isset($_POST['demo']) && $_POST['demo']) ? $_POST['demo'] : 'shop1';
        $index = (isset($_POST['index']) && $_POST['index']) ? $_POST['index'] : 0;

        $importer = new JMS_WP_Import();        
        $theme_xml = get_template_directory() . '/inc/admin/data/' . $demo . '/content.xml';
        
		
        $importer->fetch_attachments = true;
		
        $loop = (int)(ini_get('max_execution_time') / 60);
        if ($loop < 1) $loop = 1;
        if ($loop > 10) $loop = 10;
        $i = 0;		
        while ($i < $loop) {
            $response = $importer->import($theme_xml, $process, $index);
            if (isset($response['count']) && isset($response['index']) && $response['count'] && $response['index'] && $response['index'] < $response['count']) {
                $i++;
                $index = $response['index'];
            } else {
                break;
            }
        }
        echo json_encode($response);
        ob_start();
		
        if ($response['process'] == 'complete' && $demo != 'shortcodes') {
            // Set woocommerce pages
            $woopages = array(
                'woocommerce_shop_page_id' => 'Shop',
                'woocommerce_cart_page_id' => 'Cart',
                'woocommerce_checkout_page_id' => 'Checkout',
                'woocommerce_myaccount_page_id' => 'My Account'
            );
            foreach ($woopages as $woo_page_name => $woo_page_title) {
                $woopage = get_page_by_title( $woo_page_title );
                if (isset($woopage) && $woopage->ID) {
                    update_option($woo_page_name, $woopage->ID); // Front Page
                }
            }

            // We no longer need to install pages
            $notices = array_diff( get_option( 'woocommerce_admin_notices', array() ), array( 'install', 'update' ) );
            update_option( 'woocommerce_admin_notices', $notices );
            delete_option( '_wc_needs_pages' );
            delete_transient( '_wc_activation_redirect' );

            // Set imported menus to registered theme locations
            $locations = get_theme_mod( 'nav_menu_locations' ); // registered menu locations in theme
            $menus = wp_get_nav_menus(); // registered menus
			
            if ($menus) {
                foreach($menus as $menu) { // assign menus to theme locations
                    if( $menu->name == 'Primary Menu' ) {
                        $locations['primary-menu'] = $menu->term_id;
                    } else if( $menu->name == 'Footer Menu' ) {
                        $locations['footer-menu'] = $menu->term_id;
                    }
                }
            }
            set_theme_mod( 'nav_menu_locations', $locations ); // set menus to locations
			//remove megamenu from hidden meta box
			$meta_boxes_hidden = get_user_option( "metaboxhidden_nav-menus" );
			$hidden_meta_boxes = array();
			foreach ( $meta_boxes_hidden as $meta_box ) {
				if($meta_box != 'mega_menu_meta_box')
					$hidden_meta_boxes[] = $meta_box;
			}
			$user = wp_get_current_user();
			update_user_option( $user->ID, 'metaboxhidden_nav-menus', $hidden_meta_boxes, true );

			//update megamenu type
			if ($menus) {
				$cur_data = array();
                foreach($menus as $menu) { // assign menus to theme locations
					$data_menu_update = array();
					$data_menu_update['event'] = 'hover';
                    if( $menu->name == 'Primary Menu' ) {
						$data_menu_update['type'] = 'horizonal';
                        $cur_data[$menu->term_id] = $data_menu_update;
                    }
					$cur_data[$menu->term_id] = $data_menu_update;
                }
				update_option( 'jmsmegamenu_options', $cur_data );
            }
			//Set Show Logo for Logo Menu			
			/*$_mainmenu = wp_get_nav_menu_object('Main Menu');
			$data_menu_update = array();
			$_menuitems = wp_get_nav_menu_items('Main Menu');
			$logo_menu_id = null;
			for($i = 0; $i < count($_menuitems); $i++) {
				$_menuitem = $_menuitems[$i];
				if($_menuitem->post_title == 'Logo') {
					$logo_menu_id = $_menuitem->ID;
					break;
				}	
			}			
			if($logo_menu_id) {
				$data_menu_update[$logo_menu_id]['show_logo'] = 1;
				$cur_data[ $_mainmenu->term_id ] = $data_menu_update;
				update_option( 'jms_data_megamenu', $cur_data );
			}*/	
			
            // Set reading options
            $homepage = get_page_by_title( 'Home' );
			$posts_page = get_page_by_title( 'Blog' );
            if ($demo == 'shop1') {
				$homepage = get_page_by_title( 'Home 1 - Default' );
            } else if ($demo == 'shop2') {
                $homepage = get_page_by_title( 'Home 2 – Modern' );
            } else if ($demo == 'shop3') {
                $homepage = get_page_by_title( 'Home 3 – Hero Slider' );
            } else if ($demo == 'shop4') {
                $homepage = get_page_by_title( 'Home 4 – Fullwidth' );
            } else if ($demo == 'shop5') {
                $homepage = get_page_by_title( 'Home 5 – Minimal' );
            } else if ($demo == 'shop6') {
                $homepage = get_page_by_title( 'Home 6 – Boxed' );
            } else if ($demo == 'shop7') {
                $homepage = get_page_by_title( 'Home 7 – Left Menu' );
            } else if ($demo == 'shop8') {
                $homepage = get_page_by_title( 'Home 8 – Parallax' );
            } else if ($demo == 'shop9') {
                $homepage = get_page_by_title( 'Home 9 – Full Slider' );
            } else if ($demo == 'shop10') {
                $homepage = get_page_by_title( 'Home 10' );
            } else if ($demo == 'shop11') {
                $homepage = get_page_by_title( 'Home 11' );
            } else if ($demo == 'shop12') {
                $homepage = get_page_by_title( 'Home 12' );
            } else if ($demo == 'shop13') {
                $homepage = get_page_by_title( 'Home 13' );
            } else if ($demo == 'shop14') {
                $homepage = get_page_by_title( 'Home 14 - Categories Grid' );
            }
			
			
			
			if ($homepage && $homepage->ID) {
				update_option('show_on_front', 'page');
                update_option('page_on_front', $homepage->ID); // Front Page
            }
            if ($posts_page && $posts_page->ID) {
                update_option('page_for_posts', $posts_page->ID); // Blog Page
            }

            // Flush rules after install
            flush_rewrite_rules();
        }
        ob_end_clean();
    }
    die();
}

function jms_import_widgets() {
    if ( current_user_can( 'manage_options' ) ) {
        $demo = (isset($_POST['demo']) && $_POST['demo']) ? $_POST['demo'] : 'shop1';
        // Import widgets
        ob_start();
        include(get_template_directory() . '/inc/admin/data/' . $demo . '/widget_data.json');
        $widget_data = ob_get_clean();

        jms_import_widget_data( $widget_data );
		//Set Menu for Information Widget 
		$_informenu = wp_get_nav_menu_object('Information');			
		if($_informenu->term_id) {
			$data_widget_nav_menu = array();
			$data_widget_nav_menu[ 5 ]['title'] = 'Information';
			$data_widget_nav_menu[ '_multiwidget' ] = 1;
			$data_widget_nav_menu[ 5 ]['nav_menu'] = $_informenu->term_id;
			update_option( 'widget_nav_menu', $data_widget_nav_menu );
		}	
        echo __('Successfully imported widgets!', 'fluent');
    }
    die();
}


function jms_import_options() {
    if ( current_user_can( 'manage_options' ) ) {
        $demo = (isset($_POST['demo']) && $_POST['demo']) ? $_POST['demo'] : 'shop1';

        ob_start();
        include(get_template_directory() . '/inc/admin/data/' . $demo . '/theme_options.php');
        $theme_options = ob_get_clean();

        ob_start();
        $options = json_decode($theme_options, true);
        ob_clean();
        ob_end_clean();

        try {
            update_option( 'jms_4life_option', $options );
            echo __('Successfully imported theme options!', 'fluent');
        } catch (Exception $e) {
            echo __('Successfully imported theme options!', 'fluent');
        }

    }
    die();
}

// Parsing Widgets Function
// Reference: http://wordpress.org/plugins/widget-settings-importexport/
function jms_import_widget_data( $widget_data ) {
    $json_data = $widget_data;
    $json_data = json_decode( $json_data, true );

    $sidebar_data = $json_data[0];
    $widget_data = $json_data[1];

    foreach ( $widget_data as $widget_data_title => $widget_data_value ) {
        $widgets[ $widget_data_title ] = '';
        foreach( $widget_data_value as $widget_data_key => $widget_data_array ) {
            if( is_int( $widget_data_key ) ) {
                $widgets[$widget_data_title][$widget_data_key] = 'on';
            }
        }
    }
    unset($widgets[""]);

    foreach ( $sidebar_data as $title => $sidebar ) {
        $count = count( $sidebar );
        for ( $i = 0; $i < $count; $i++ ) {
            $widget = array( );
            $widget['type'] = trim( substr( $sidebar[$i], 0, strrpos( $sidebar[$i], '-' ) ) );
            $widget['type-index'] = trim( substr( $sidebar[$i], strrpos( $sidebar[$i], '-' ) + 1 ) );
            if ( !isset( $widgets[$widget['type']][$widget['type-index']] ) ) {
                unset( $sidebar_data[$title][$i] );
            }
        }
        $sidebar_data[$title] = array_values( $sidebar_data[$title] );
    }

    foreach ( $widgets as $widget_title => $widget_value ) {
        foreach ( $widget_value as $widget_key => $widget_value ) {
            $widgets[$widget_title][$widget_key] = $widget_data[$widget_title][$widget_key];
        }
    }

    $sidebar_data = array( array_filter( $sidebar_data ), $widgets );
    jms_parse_import_data( $sidebar_data );
}

function jms_parse_import_data( $import_array ) {
    global $wp_registered_sidebars;
    $sidebars_data = $import_array[0];
    $widget_data = $import_array[1];
    $current_sidebars = get_option( 'sidebars_widgets' );
    $new_widgets = array( );

    foreach ( $sidebars_data as $import_sidebar => $import_widgets ) :

        foreach ( $import_widgets as $import_widget ) :
            //if the sidebar exists
            if ( isset( $wp_registered_sidebars[$import_sidebar] ) ) :
                $title = trim( substr( $import_widget, 0, strrpos( $import_widget, '-' ) ) );
                $index = trim( substr( $import_widget, strrpos( $import_widget, '-' ) + 1 ) );
                $current_widget_data = get_option( 'widget_' . $title );
                $new_widget_name = jms_get_new_widget_name( $title, $index );
                $new_index = trim( substr( $new_widget_name, strrpos( $new_widget_name, '-' ) + 1 ) );

                if ( !empty( $new_widgets[ $title ] ) && is_array( $new_widgets[$title] ) ) {
                    while ( array_key_exists( $new_index, $new_widgets[$title] ) ) {
                        $new_index++;
                    }
                }
                $current_sidebars[$import_sidebar][] = $title . '-' . $new_index;
                if ( array_key_exists( $title, $new_widgets ) ) {
                    $new_widgets[$title][$new_index] = $widget_data[$title][$index];
                    $multiwidget = $new_widgets[$title]['_multiwidget'];
                    unset( $new_widgets[$title]['_multiwidget'] );
                    $new_widgets[$title]['_multiwidget'] = $multiwidget;
                } else {
                    $current_widget_data[$new_index] = $widget_data[$title][$index];
                    $current_multiwidget = (isset($current_widget_data['_multiwidget']))?$current_widget_data['_multiwidget']:'';
                    $new_multiwidget = isset($widget_data[$title]['_multiwidget']) ? $widget_data[$title]['_multiwidget'] : false;
                    $multiwidget = ($current_multiwidget != $new_multiwidget) ? $current_multiwidget : 1;
                    unset( $current_widget_data['_multiwidget'] );
                    $current_widget_data['_multiwidget'] = $multiwidget;
                    $new_widgets[$title] = $current_widget_data;
                }

            endif;
        endforeach;
    endforeach;

    if ( isset( $new_widgets ) && isset( $current_sidebars ) ) {
        update_option( 'sidebars_widgets', $current_sidebars );

        foreach ( $new_widgets as $title => $content )
            update_option( 'widget_' . $title, $content );

        return true;
    }

    return false;
}

function jms_get_new_widget_name( $widget_name, $widget_index ) {
    $current_sidebars = get_option( 'sidebars_widgets' );
    $all_widget_array = array( );
    foreach ( $current_sidebars as $sidebar => $widgets ) {
        if ( !empty( $widgets ) && is_array( $widgets ) && $sidebar != 'wp_inactive_widgets' ) {
            foreach ( $widgets as $widget ) {
                $all_widget_array[] = $widget;
            }
        }
    }
    while ( in_array( $widget_name . '-' . $widget_index, $all_widget_array ) ) {
        $widget_index++;
    }
    $new_widget_name = $widget_name . '-' . $widget_index;
    return $new_widget_name;
}
function jms_import_sliders() {
	global $wpdb;
    if ( current_user_can( 'manage_options' ) ) {
        $demo = (isset($_POST['demo']) && $_POST['demo']) ? $_POST['demo'] : 'shop1';
        // Import slider
		$slider_query = '';
        include(get_template_directory() . '/inc/admin/data/' . $demo . '/sliders.php');
        $return = true;
		if (isset($slider_query) && !empty($slider_query))
		{
			$slider_query = str_replace( '_DB_PREFIX_', $wpdb->prefix, $slider_query );
			$status_query = "SHOW TABLE STATUS WHERE Name = '".$wpdb->prefix."posts'";
			$status = $wpdb->get_results( $status_query );
			$mysql_engine = $status[0]->Engine;
			$slider_query = str_replace( '_MYSQL_ENGINE_', $mysql_engine, $slider_query );

			$db_data_settings = preg_split("/;\s*[\r\n]+/", $slider_query);
			foreach ($db_data_settings as $query)
			{
				$query = trim($query);
				if (!empty($query))
				{
					if (!$wpdb->query($query))
						$return = false;
				}
			}
			if(!$return)
				echo __('Fail when import sliders!', 'fluent');
			else
				echo __('Successfully imported sliders!', 'fluent');
		} else {
			echo __('Check sliders.php again, file is empty!', 'fluent');
		}
    }
    die();
}
