<?php

    /**
     * ReduxFramework Barebones Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    /**
     * ------------------------------------------------------------------------------------------------
     * Prepare CSS selectors for theme settions (colors, borders, typography etc.)
     * ------------------------------------------------------------------------------------------------
     */
    include FLUENT_PATH . '/inc/functions/selectors.php';

    // This is your option name where all the Redux data is stored.
    $opt_name = "fluent_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => false,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'Theme Options', 'fluent' ),
        'page_title'           => esc_html__( 'Theme Options', 'fluent' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => false,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',

        'page_permissions'     => 'administrator',
        // Permissions needed to access the options panel.
        'menu_icon'            => 'dashicons-palmtree',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '_options',
        // Page slug used to denote the panel
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        //'compiler'             => true,
        //'hide_reset' => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'https://facebook.com/joommasters2015',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => 'https://twitter.com/joommasters',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => 'https://www.linkedin.com/company/joommasters',
        'title' => 'Find us on LinkedIn',
        'icon'  => 'el el-linkedin'
    );


    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'fluent' ),
            'content' => esc_html__( '<p>This is the tab content, HTML is allowed.</p>', 'fluent' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'fluent' ),
            'content' => esc_html__( '<p>This is the tab content, HTML is allowed.</p>', 'fluent' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( 'This is the sidebar content, HTML is allowed.', 'fluent' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'General', 'fluent' ),
        'id'     => 'general',
        'icon'   => 'el el-dashboard',
        'fields' => array(
            array(
                'id'       => 'login-logo',
                'type'     => 'media',
                'url'      => true,
                'title'    => esc_html__('Control Panel Login Logo', 'fluent'),
                'subtitle' => esc_html__('Max width: 302px - Max height: 67px','fluent')
            ),
            array(
                'id'      => 'site-loader',
                'type'    => 'switch',
                'title'   => esc_html__('Site Loader', 'fluent'),
                'on'      => esc_html__('On','fluent'),
                'off'     => esc_html__('Off','fluent'),
                'default' => true,
            ),
            array(
                'id'       => 'site-loader-style',
                'type'     => 'select',
                'title'    => esc_html__( 'Site Loader Style', 'fluent' ),
                'options'  => array(
                    '1' => esc_html__( 'Style 1', 'fluent' ),
                    '2' => esc_html__( 'Style 2', 'fluent' ),
                    '3' => esc_html__( 'Style 3', 'fluent' ),
                    '4' => esc_html__( 'Style 4', 'fluent' ),
                    '5' => esc_html__( 'Style 5', 'fluent' ),
                    '6' => esc_html__( 'Style 6', 'fluent' ),
                ),
                'default'  => '5',
                'required' => array( 'site-loader', '=', 1 )
            ),
            array(
                'id'       => 'browser-smooth-scroll',
                'type'     => 'switch',
                'title'    => esc_html__('Smooth Browser Scroll', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 0,
            ),
            array(
                'id'       => 'back-to-top',
                'type'     => 'switch',
                'title'    => esc_html__( 'Show Back To Top Button', 'fluent' ),
                'desc'     => esc_html__( 'Show back to top button.', 'fluent' ),
                'on'       => esc_html__( 'On', 'fluent' ),
                'off'      => esc_html__( 'Off', 'fluent' ),
                'default'  => 1,
            ),
        )
    ) );

    // Top bar
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Top Bar', 'fluent' ),
        'id'     => 'top-bar',
        'icon'   => 'el el-circle-arrow-up',
        'fields' => array(
            array(
                'id'          => 'topbar',
                'type'        => 'switch',
                'title'       => esc_html__('Enable Top Bar', 'fluent'),
                'default'     => false,
            ),
            array(
                'id'       => 'section-topbar-left-start',
                'type'     => 'section',
                'title'    => esc_html__( 'Top Bar Left', 'fluent' ),
                'indent'   => true,
            ),
            array(
                'id'       => 'topbar-phone',
                'type'     => 'text',
                'title'    => esc_html__('Phone', 'fluent'),
                'default'  => '01 1 2268 7749'
            ),
            array(
                'id'       => 'topbar-email',
                'type'     => 'text',
                'title'    => esc_html__('Email', 'fluent'),
                'default'  => 'fluentcare@demo.com'
            ),
            array(
                'id'       => 'section-topbar-left-end',
                'type'     => 'section',
                'indent'   => true,
            ),
            //end topbar left
            array(
                'id'       => 'section-topbar-right-start',
                'type'     => 'section',
                'title'    => esc_html__( 'Top Bar Right', 'fluent' ),
                'indent'   => true,
            ),
            array(
                'id'          => 'show-account-box',
                'type'        => 'switch',
                'title'       => esc_html__('Show Login/ My Account', 'fluent'),
                'default'     => true,
            ),
            array(
                'id'          => 'show-language-box',
                'type'        => 'switch',
                'title'       => esc_html__('Show Language', 'fluent'),
                'default'     => false,
            ),
            array(
                'id'          => 'language-name-1',
                'type'        => 'text',
                'title'       => esc_html__('1st Language Name', 'fluent'),
                'default'     => 'English',
                'required'    => array( 'show-language-box', '=', 1 )
            ),
            array(
                'id'          => 'language-link-1',
                'type'        => 'text',
                'title'       => esc_html__('1st Language URL', 'fluent'),
                'default'     => '#',
                'required'    => array( 'show-language-box', '=', 1 )
            ),
            array(
                'id'          => 'language-name-2',
                'type'        => 'text',
                'title'       => esc_html__('2nd Language Name', 'fluent'),
                'default'     => 'Italiano',
                'required'    => array( 'show-language-box', '=', 1 )
            ),
            array(
                'id'          => 'language-link-2',
                'type'        => 'text',
                'title'       => esc_html__('2nd Language URL', 'fluent'),
                'default'     => '#',
                'required'    => array( 'show-language-box', '=', 1 )
            ),
            array(
                'id'          => 'language-name-3',
                'type'        => 'text',
                'title'       => esc_html__('3rd Language Name', 'fluent'),
                'default'     => '',
                'required'    => array( 'show-language-box', '=', 1 )
            ),
            array(
                'id'          => 'language-link-3',
                'type'        => 'text',
                'title'       => esc_html__('3rd Language URL', 'fluent'),
                'default'     => '',
                'required'    => array( 'show-language-box', '=', 1 )
            ),
            array(
                'id'          => 'show-currency-box',
                'type'        => 'switch',
                'title'       => esc_html__('Show Currency', 'fluent'),
                'default'     => false,
            ),
            array(
                'id'          => 'show-social-box',
                'type'        => 'switch',
                'title'       => esc_html__('Show Social', 'fluent'),
                'default'     => false,
            ),
            array(
                'id'       => 'section-topbar-right-end',
                'type'     => 'section',
                'indent'   => true,
            ),
        )
    ) );

    // Header
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Header', 'fluent' ),
        'id'     => 'header',
        'icon'   => 'el el-circle-arrow-up',
        'fields' => array(
            array(
                'id'       => 'header-layout',
                'type'     => 'select',
                'title'    => esc_html__( 'Header Layout', 'fluent' ),
                'subtitle' => esc_html__( 'Set the header layout', 'fluent' ),
                'options'  => array(
                    '1' => esc_html__( 'Header 1', 'fluent' ),
                    '2' => esc_html__( 'Header 2', 'fluent' ),
                    '3' => esc_html__( 'Header 3', 'fluent' ),
                    '4' => esc_html__( 'Header 4', 'fluent' ),
                    '5' => esc_html__( 'Header 5 - Left Menu', 'fluent' ),
                ),
                'default'  => '2',
            ),
            array(
                'id'       => 'header-fullwidth',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Fullwidth', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'          => 'sticky-header',
                'type'        => 'switch',
                'title'       => esc_html__('Sticky Header', 'fluent'),
                'subtitle'    => esc_html__('How to display the header menu on scroll.', 'fluent'),
                'default'     => false,
            ),
            array(
                'id'       => 'section-header-left-start',
                'title'    => esc_html__('Header Left', 'fluent'),
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'       => 'header-logo',
                'type'     => 'media',
                'url'      => true,
                'title'    => esc_html__('Logo', 'fluent'),
            ),
            array(
                'id'       => 'section-header-left-end',
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'       => 'section-header-right-start',
                'title'    => esc_html__('Header Right', 'fluent'),
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'          => 'show-search-form',
                'type'        => 'switch',
                'title'       => esc_html__('Show Search Form', 'fluent'),
                'default'     => true
            ),
            array(
                'id'          => 'show-cart-button',
                'type'        => 'switch',
                'title'       => esc_html__('Show Cart Button', 'fluent'),
                'default'     => true
            ),
            array(
                'id'          => 'show-toggle-sidebar',
                'type'        => 'switch',
                'title'       => esc_html__('Show Toggle Sidebar Button', 'fluent'),
                'default'     => true
            ),
            array(
                'id'       => 'section-header-right-end',
                'type'     => 'section',
                'indent'   => true,
            ),
        )
    ) );

    // -> START Footer Fields
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Footer', 'fluent' ),
        'id'     => 'footer',
        'icon'   => 'el el-circle-arrow-down',
        'fields' => array(
            array(
                'id'       => 'footer-fullwidth',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Fullwidth', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 0,
            ),
            array(
                'id'       => 'footer-widget-area',
                'type'     => 'switch',
                'title'    => esc_html__('Footer Widget Area', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'       => 'footer-column',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Footer Column', 'fluent' ),
                'options'  => array(
                    '1' => array(
                        'alt' => esc_html__('1 Column', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/one.jpg'
                    ),
                    '2' => array(
                        'alt' => esc_html__('2 Columns', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/two.jpg'
                    ),
                    '3' => array(
                        'alt' => esc_html__('3 Columns', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/three.jpg'
                    ),
                    '4' => array(
                        'alt' => esc_html__('4 Columns', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/four.jpg'
                    )
                ),
                'default'  => '4',
                'required' => array( 'footer-widget-area', '=', 1 )
            ),
            array(
                'id'       => 'footer-copyright',
                'type'     => 'textarea',
                'title'    => esc_html__('Copyright', 'fluent'),
                'subtitle' => esc_html__('HTML is allowed.', 'fluent'),
                'validate' => 'html',
                'default'  => 'Copyright 2017. All rights reserved. Design by <a href="#">JoomMasters.com</a>.',
            ),
        )
    ) );
    /*
     * <--- END SECTIONS
     */

    // BLOG
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Blog', 'fluent' ),
        'id'     => 'blog',
        'icon'   => 'el el-shopping-cart',
        'fields' => array()
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Blog List', 'fluent' ),
        'id'         => 'blog-list',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'blog-title',
                'type'     => 'text',
                'title'    => esc_html__('Blog Title', 'fluent'),
                'default'  => esc_html__('Blog', 'fluent')
            ),
            array(
                'id'      => 'blog-background',
                'type'    => 'background',
                'title'   => esc_html__( 'Page Title Background', 'fluent' ),
                'default' => array(
                    'background-image'      => '',
                    'background-color'      => ''
                )
            ),
            array(
                'id'       => 'blog-style',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Blog Style', 'fluent' ),
                'subtitle' => esc_html__( 'Display blog listing as grid or masonry.', 'fluent' ),
                'options'  => array(
                    'list' => array(
                        'alt' => 'List',
                        'img' => FLUENT_URL . '/assets/images/layout/list.jpg'
                    ),
                    'grid' => array(
                        'alt' => 'Grid',
                        'img' => FLUENT_URL . '/assets/images/layout/grid.jpg'
                    ),
                    'masonry' => array(
                        'alt' => 'Masonry',
                        'img' => FLUENT_URL . '/assets/images/layout/masonry.jpg'
                    )
                ),
                'default'  => 'list'
            ),
            array(
                'id'       => 'blog-column',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Blog Column', 'fluent' ),
                'options'  => array(
                    '2' => array(
                        'alt' => esc_html__('2 Columns', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/two.jpg'
                    ),
                    '3' => array(
                        'alt' => esc_html__('3 Columns', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/three.jpg'
                    ),
                    '4' => array(
                        'alt' => esc_html__('4 Columns', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/four.jpg'
                    )
                ),
                'default'  => '2',
                'required' => array( 'blog-style', '!=', 'list' )
            ),
            array(
                'id'       => 'blog-pagination-type',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Pagination Type', 'fluent' ),
                'options'  => array(
                    'number-pagination' => array(
                        'alt' => 'Number Pagination',
                        'img' => FLUENT_URL . '/assets/images/layout/number.jpg'
                    ),
                    'load-more' => array(
                        'alt' => 'Load More',
                        'img' => FLUENT_URL . '/assets/images/layout/load-more.jpg'
                    ),
                    'infinite-scroll' => array(
                        'alt' => 'Infinite Scroll',
                        'img' => FLUENT_URL . '/assets/images/layout/infinite.jpg'
                    )
                ),
                'default'  => 'number-pagination',
            ),
            array(
                'id'       => 'blog-layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Blog Layout', 'fluent' ),
                'subtitle' => esc_html__( 'Select blog layout with sidebar postion.', 'fluent' ),
                'options'  => array(
                    'left' => array(
                        'alt' => 'Left Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/left-sidebar.jpg'
                    ),
                    'no' => array(
                        'alt' => 'No Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/no-sidebar.jpg'
                    ),
                    'right' => array(
                        'alt' => 'Right Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/right-sidebar.jpg'
                    ),
                ),
                'default'  => 'left'
            )
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Blog Single', 'fluent' ),
        'id'     => 'blog-single',
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'show-feature-image',
                'type'     => 'switch',
                'title'    => esc_html__('Featured Image', 'fluent'),
                'on'       => esc_html__('Show', 'fluent'),
				'off'      => esc_html__('Hide', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'       => 'show-related-posts',
                'type'     => 'switch',
                'title'    => esc_html__('Show Related Posts', 'fluent'),
                'on'       => esc_html__('Show', 'fluent'),
				'off'      => esc_html__('Hide', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'       => 'show-post-navigation',
                'type'     => 'switch',
                'title'    => esc_html__('Show Post Navigation', 'fluent'),
                'on'       => esc_html__('Show', 'fluent'),
				'off'      => esc_html__('Hide', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'       => 'blog-single-layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Blog Single Layout', 'fluent' ),
                'subtitle' => esc_html__( 'Select blog single layout with sidebar postion.', 'fluent' ),
                'options'  => array(
                    'left' => array(
                        'alt' => 'Left Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/left-sidebar.jpg'
                    ),
                    'no' => array(
                        'alt' => 'No Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/no-sidebar.jpg'
                    ),
                    'right' => array(
                        'alt' => 'Right Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/right-sidebar.jpg'
                    ),
                ),
                'default'  => 'left'
            ),
        )
    ) );

    // Portfolio
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Portfolio', 'fluent' ),
        'id'     => 'portfolio',
        'icon'   => 'el el-filter',
        'fields' => array(
            array(
                'id'       => 'portfolio-title',
                'type'     => 'text',
                'title'    => esc_html__('Portfolio Title', 'fluent'),
                'default'  => esc_html__('Portfolio', 'fluent')
            ),
            array(
                'id'      => 'portfolio-background',
                'type'    => 'background',
                'title'   => esc_html__( 'Page Title Background', 'fluent' ),
                'default' => array(
                    'background-image'      => '',
                    'background-color'      => ''
                )
            ),
            array(
                'id'       => 'portfolio-fullwidth',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Fullwidth', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 0,
            ),
            array(
                'id'       => 'portfolio-style',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Portfolio Style', 'fluent' ),
                'options'  => array(
                    'grid' => array(
                        'alt' => 'Grid',
                        'img' => FLUENT_URL . '/assets/images/layout/grid.jpg'
                    ),
                    'masonry' => array(
                        'alt' => 'Masonry',
                        'img' => FLUENT_URL . '/assets/images/layout/masonry.jpg'
                    )
                ),
                'default'  => 'masonry'
            ),
            array(
                'id'       => 'portfolio-column',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Portfolio Column', 'fluent' ),
                'options'  => array(
                    '2' => array(
                        'alt' => '2 Columns',
                        'img' => FLUENT_URL . '/assets/images/layout/two.jpg'
                    ),
                    '3' => array(
                        'alt' => '3 Columns',
                        'img' => FLUENT_URL . '/assets/images/layout/three.jpg'
                    ),
                    '4' => array(
                        'alt' => '4 Columns',
                        'img' => FLUENT_URL . '/assets/images/layout/four.jpg'
                    )
                ),
                'default'  => '3'
            ),
            array(
                'id'       => 'portfolio-number-per-page',
                'type'     => 'text',
                'title'    => esc_html__( 'Per page', 'fluent' ),
                'subtitle' => esc_html__( 'How much items per page to show.', 'fluent' ),
                'validate' => 'numeric',
                'default'  => '12'
            ),
            array(
                'id'       => 'portfolio-pagination-type',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Pagination Type', 'fluent' ),
                'options'  => array(
                    'number-pagination' => array(
                        'alt' => 'Number Pagination',
                        'img' => FLUENT_URL . '/assets/images/layout/number.jpg'
                    ),
                    'load-more' => array(
                        'alt' => 'Load More',
                        'img' => FLUENT_URL . '/assets/images/layout/load-more.jpg'
                    ),
                    'infinite-scroll' => array(
                        'alt' => 'Infinite Scroll',
                        'img' => FLUENT_URL . '/assets/images/layout/infinite.jpg'
                    )
                ),
                'default'  => 'number-pagination',
            )
        )
    ) );

    // Woocommerce
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Woocommerce', 'fluent' ),
        'id'     => 'woocommerce',
        'icon'   => 'el el-shopping-cart',
        'fields' => array()
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'General Setting', 'fluent' ),
        'id'         => 'wc_general_setting',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'          => 'wc-page-title',
                'type'        => 'switch',
                'title'       => esc_html__('Woocommerce Page Title', 'fluent'),
                'default'     => true,
            ),
            array(
                'id'      => 'wc-shop-title',
                'type'    => 'text',
                'title'   => esc_html__('Page Title', 'fluent'),
                'default' => esc_html__('Shop', 'fluent'),
                'required' => array( 'wc-page-title', '=', '1' )
            ),
            array(
                'id'                    => 'wc-shop-background',
                'type'                  => 'background',
                'title'                 => esc_html__( 'Page Title Background', 'fluent' ),
                'default'  => array(
                    'background-image'      => '',
                    'background-color'      => ''
                ),
                'required' => array( 'wc-page-title', '=', '1' )
            ),
            array(
                'id'       => 'wc-shop-fullwidth',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Fullwidth', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 0,
            ),
            array(
                'id'       => 'wc-add-to-cart-style',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Add To Cart Style', 'fluent' ),
                'options'  => array(
                    'default'        => esc_html__('Default', 'fluent'),
                    'toggle-sidebar' => esc_html__('Toggle Sidebar', 'fluent'),
                    'toggle-bottom'  => esc_html__('Toggle Bottom', 'fluent'),
                    'preview-popup'  => esc_html__('Preview Popup', 'fluent'),
                ),
                'default'  => 'default'
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Sub Category Setting', 'fluent' ),
        'id'         => 'wc_sub_category_setting',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'wc-sub-category-column',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Woocomerce Column Number', 'fluent' ),
                'options'  => array(
                    '2' => array(
                        'alt' => '2 Columns',
                        'img' => FLUENT_URL . '/assets/images/layout/two.jpg'
                    ),
                    '3' => array(
                        'alt' => '3 Columns',
                        'img' => FLUENT_URL . '/assets/images/layout/three.jpg'
                    ),
                    '4' => array(
                        'alt' => '4 Columns',
                        'img' => FLUENT_URL . '/assets/images/layout/four.jpg'
                    ),
                    '6' => array(
                        'alt' => '6 Columns',
                        'img' => FLUENT_URL . '/assets/images/layout/six.jpg'
                    )
                ),
                'default'  => '4'
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Product List Setting', 'fluent' ),
        'id'         => 'wc_product_list_setting',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'section-shop-action-start',
                'type'     => 'section',
                'title'    => esc_html__( 'Shop Action', 'fluent' ),
                'indent'   => true,
            ),
            array(
                'id'       => 'wc-view-mode',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Grid/List', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'       => 'wc-category-tab',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Category Tab', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 0,
            ),
            array(
                'id'       => 'wc-filter',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Filter', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'       => 'wc-filter-style',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Filter Style', 'fluent' ),
                'options'  => array(
                    'filter-off-canvas' => esc_html__('Off Canvas Filter', 'fluent'),
                    'filter-top'        => esc_html__('Top Filter', 'fluent'),
                ),
                'default'  => 'filter-off-canvas',
                'required' => array( 'wc-filter', '=', '1' )
            ),
			array(
                'id'       => 'wc-filter-ajax',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Ajax Shop', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 1,
				'required' => array( 'wc-filter', '=', '1' )
            ),
            array(
                'id'       => 'wc-ordering',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Catalog Ordering', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 0,
				'required' => array( 'wc-filter', '=', '0' )
            ),
            array(
                'id'       => 'section-shop-action-end',
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'       => 'section-shop-information-start',
                'type'     => 'section',
                'title'    => esc_html__( 'Shop Information', 'fluent' ),
                'indent'   => true,
            ),
			array(
                'id'       => 'wc-shop-heading',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Shop Heading', 'fluent' ),
                'options'  => array(
                    'title_background' => esc_html__('Background Image + Title', 'fluent'),
                    'slideshow'        => esc_html__('Slideshow', 'fluent'),
					'none'        	 => esc_html__('None', 'fluent')
                ),
                'default'  => 'title_background',
                'required' => array( 'wc-filter', '=', '1' )
            ),
            array(
                'id'       => 'wc-product-style',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Product Style', 'fluent' ),
                'options'  => array(
                    'style-1' => array(
                        'alt' => 'Product Style 1',
                        'img' => FLUENT_URL . '/assets/images/product-style/product-style-1.jpg'
                    ),
                    'style-2' => array(
                        'alt' => 'Product Style 2',
                        'img' => FLUENT_URL . '/assets/images/product-style/product-style-2.jpg'
                    ),
                ),
                'default'  => 'style-1'
            ),
            array(
                'id'       => 'wc-quick-view',
                'type'     => 'switch',
                'title'    => esc_html__('Show/Hide Quickview Button', 'fluent'),
                'on'       => esc_html__('Show', 'fluent'),
				'off'      => esc_html__('Hide', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'       => 'wc-wishlist',
                'type'     => 'switch',
                'title'    => esc_html__('Show/Hide Wishlist', 'fluent'),
                'on'       => esc_html__('Show', 'fluent'),
				'off'      => esc_html__('Hide', 'fluent'),
				'default'  => 1,
            ),
            array(
                'id'       => 'wc-category-name',
                'type'     => 'switch',
                'title'    => esc_html__('Show/Hide Category Name', 'fluent'),
                'on'       => esc_html__('Show', 'fluent'),
				'off'      => esc_html__('Hide', 'fluent'),
				'default'  => 1,
                'required' => array( 'wc-product-style', '=', 'style-1' )
            ),
            array(
                'id'    => 'show-attribute-variation',
                'type'  => 'switch',
                'title' => esc_html__('Show Attribute Variation','fluent'),
                'desc'  => esc_html__('Show attribute variation on product box', 'fluent'),
                'on'    => esc_html__('Show','fluent'),
				'off'   => esc_html__('Hide','fluent'),
				'default' => 1,
            ),
            array(
                'id'       => 'wc-product-hover-style',
                'type'     => 'select',
                'title'    => esc_html__( 'Product Box Hover', 'fluent' ),
                'options'  => array(
                    'blur' => esc_html__( 'Image Blur', 'fluent' ),
                    'swap' => esc_html__( 'Image Swap', 'fluent' ),
                ),
                'default'  => 'swap',
            ),
            array(
                'id'       => 'wc-number-per-page',
                'type'     => 'text',
                'title'    => esc_html__( 'Per page', 'fluent' ),
                'subtitle' => esc_html__( 'How much items per page to show.', 'fluent' ),
                'validate' => 'numeric',
                'default'  => '12'
            ),
            array(
                'id'       => 'wc-product-column',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Columns', 'fluent' ),
                'options'  => array(
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                    '5' => '5',
                    '6' => '6',
                ),
                'default'  => '4'
            ),
            array(
                'id'       => 'wc-archive-style',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Product List Style', 'fluent' ),
                'options'  => array(
                    'grid' => array(
                        'alt' => 'Grid',
                        'img' => FLUENT_URL . '/assets/images/layout/grid.jpg'
                    ),
                    'masonry' => array(
                        'alt' => 'Masonry',
                        'img' => FLUENT_URL . '/assets/images/layout/masonry.jpg'
                    )
                ),
                'default'  => 'grid'
            ),
            array(
                'id'       => 'wc-gutter-space',
                'type'     => 'slider',
                'title'    => esc_html__('Gutter Space','fluent'),
                'min'      => 0,
                'max'      => 60,
                'step'     => 10,
                'default'  => 30,
            ),
            array(
                'id'       => 'wc-pagination-type',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Pagination Type', 'fluent' ),
                'options'  => array(
                    'number-pagination' => array(
                        'alt' => 'Number Pagination',
                        'img' => FLUENT_URL . '/assets/images/layout/number.jpg'
                    ),
                    'load-more' => array(
                        'alt' => 'Load More',
                        'img' => FLUENT_URL . '/assets/images/layout/load-more.jpg'
                    ),
                    'infinite-scroll' => array(
                        'alt' => 'Infinite Scroll',
                        'img' => FLUENT_URL . '/assets/images/layout/infinite.jpg'
                    )
                ),
                'default'  => 'number-pagination',
            ),
            array(
                'id'       => 'wc-shop-layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Product List Layout', 'fluent' ),
                'subtitle' => esc_html__( 'Select shop page layout with sidebar postion.', 'fluent' ),
                'options'  => array(
                    'left' => array(
                        'alt' => 'Left Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/left-sidebar.jpg'
                    ),
                    'no' => array(
                        'alt' => 'No Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/no-sidebar.jpg'
                    ),
                    'right' => array(
                        'alt' => 'Right Sidebar',
                        'img' => FLUENT_URL . '/assets/images/layout/right-sidebar.jpg'
                    ),
                ),
                'default'  => 'no'
            ),
            array(
                'id'       => 'section-shop-information-end',
                'type'     => 'section',
                'indent'   => true,
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Single Product Setting', 'fluent' ),
        'id'         => 'wc_single_product_setting',
        'subsection' => true,
        'fields'     => array(
            array (
                'id'       => 'single_ajax_add_to_cart',
                'type'     => 'switch',
                'title'    => esc_html__('AJAX Add to cart', 'fluent'),
                'default'  => true
            ),
            array(
                'id'       => 'wc-single-sharing',
                'type'     => 'switch',
                'title'    => esc_html__('Social Sharing', 'fluent'),
    			'default'  => 1,
            ),
            array(
                'id'       => 'wc-single-product-layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Product Page Layout', 'fluent' ),
                'subtitle' => esc_html__( 'Sidebar position.', 'fluent' ),
                'options'  => array(
                    'left' => array(
                        'alt' => esc_html__('Left Sidebar', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/left-sidebar.jpg'
                    ),
                    'no' => array(
                        'alt' => esc_html__('No Sidebar', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/no-sidebar.jpg'
                    ),
                    'right' => array(
                        'alt' => esc_html__('Right Sidebar', 'fluent'),
                        'img' => FLUENT_URL . '/assets/images/layout/right-sidebar.jpg'
                    ),
                ),
                'default'  => 'no',
            ),
        )
    ) );

    // START Typography
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Typography', 'fluent' ),
        'id'     => 'theme-typography',
        'icon'   => 'el el-font',
        'fields' => array(
            array(
                'id'       => 'section-body-font-start',
                'type'     => 'section',
                'title'    => esc_html__( 'Body Font', 'fluent' ),
                'indent'   => true,
            ),
            array(
				'id'          => 'body-font',
				'type'        => 'typography',
				'title'       => esc_html__('Font Family', 'fluent'),
                'subtitle'    => esc_html__( 'Specify the body font properties.', 'fluent' ),
				'google'      => true,
                'text-align'  => false,
                'line-height' => false,
                'font-style'  => false,
				'output'      => $fluent_selectors['main-font'],
                'letter-spacing' => true,
                'all_styles'  => true,
                'default'        => array(
                    'font-family'    => 'Raleway',
                    'font-size'      => '15',
                    'font-weight'    => '400',
                    'letter-spacing' => '0.2',
                    'color'          => '#6e6e6e',
                )
			),
            array(
                'id'       => 'section-body-font-end',
                'type'     => 'section',
                'indent'   => true
            ),
            array(
                'id'     => 'section-second-font-start',
                'type'   => 'section',
                'title'  => esc_html__('Second Font', 'fluent'),
                'indent' => true
            ),
            array(
				'id'          => 'second-font',
				'type'        => 'typography',
				'title'       => esc_html__('Font Family', 'fluent'),
                'subtitle'    => esc_html__('Title product tab, product name, price,..', 'fluent'),
                'google'      => true,
                'color'       => false,
				'text-align'  => false,
                'font-weight' => false,
                'font-size'   => false,
                'line-height' => false,
                'font-style'  => false,
				'subsets'	  => true,
                'output'      => $fluent_selectors['second-font'],
                'all_styles'  => true,
                'default'        => array()
			),
            array(
                'id'       => 'section-second-font-end',
                'type'     => 'section',
                'indent'   => true
            ),
            array(
                'id'       => 'section-menu-font-start',
                'type'     => 'section',
                'title'    => esc_html__( 'Menu', 'fluent' ),
                'indent'   => true,
            ),
            array(
                'id'             => 'menu-font',
                'type'           => 'typography',
                'title'          => esc_html__( 'Font Family', 'fluent' ),
                'google'         => true,
                'text-align'     => false,
                'line-height'    => false,
                'color'          => false,
                'subsets'	  => true,
                'output'      => $fluent_selectors['menu-font'],
                'all_styles'     => true,
                'default'        => array()
            ),
            array(
                'id'       => 'section-menu-font-end',
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'       => 'section-heading-font-start',
                'type'     => 'section',
                'title'    => esc_html__( 'Heading', 'fluent' ),
                'indent'   => true,
            ),
            array(
                'id'             => 'heading-font',
                'type'           => 'typography',
                'title'          => esc_html__( 'Font Family', 'fluent' ),
                'google'         => true,
                'font-style'     => false,
                'font-size'      => false,
                'letter-spacing' => false,
                'text-align'     => false,
                'line-height'    => false,
                'text-transform' => false,
                'subsets'	  => true,
                'output'      => $fluent_selectors['heading-font'],
                'all_styles'     => true,
                'default'        => array()
            ),
            array(
                'id'             => 'h1-font-size',
                'type'           => 'typography',
                'title'          => esc_html__( 'H1 Font Size', 'fluent' ),
                'google'         => true,
                'font-weight'    => false,
                'font-style'     => false,
                'font-family'    => false,
                'letter-spacing' => false,
                'text-align'     => false,
                'line-height'    => false,
                'text-transform' => false,
                'color'          => false,
				'subsets'	     => false,
                'default'        => array(
                    'font-size' => '36'
                )
            ),
            array(
                'id'             => 'h2-font-size',
                'type'           => 'typography',
                'title'          => esc_html__( 'H2 Font Size', 'fluent' ),
                'google'         => true,
                'font-weight'    => false,
                'font-style'     => false,
                'font-family'    => false,
                'letter-spacing' => false,
                'text-align'     => false,
                'line-height'    => false,
                'text-transform' => false,
                'color'          => false,
				'subsets'	     => false,
                'default'        => array(
                    'font-size' => '30'
                )
            ),
            array(
                'id'             => 'h3-font-size',
                'type'           => 'typography',
                'title'          => esc_html__( 'H3 Font Size', 'fluent' ),
                'google'         => true,
                'font-weight'    => false,
                'font-style'     => false,
                'font-family'    => false,
                'letter-spacing' => false,
                'text-align'     => false,
                'line-height'    => false,
                'text-transform' => false,
                'color'          => false,
				'subsets'	     => false,
                'default'        => array(
                    'font-size' => '24'
                )
            ),
            array(
                'id'             => 'h4-font-size',
                'type'           => 'typography',
                'title'          => esc_html__( 'H4 Font Size', 'fluent' ),
                'google'         => true,
                'font-weight'    => false,
                'font-style'     => false,
                'font-family'    => false,
                'letter-spacing' => false,
                'text-align'     => false,
                'line-height'    => false,
                'text-transform' => false,
                'color'          => false,
				'subsets'	     => false,
                'default'        => array(
                    'font-size' => '21'
                )
            ),
            array(
                'id'             => 'h5-font-size',
                'type'           => 'typography',
                'title'          => esc_html__( 'H5 Font Size', 'fluent' ),
                'google'         => true,
                'font-weight'    => false,
                'font-style'     => false,
                'font-family'    => false,
                'letter-spacing' => false,
                'text-align'     => false,
                'line-height'    => false,
                'text-transform' => false,
                'color'          => false,
				'subsets'	     => false,
                'default'        => array(
                    'font-size' => '18'
                )
            ),
            array(
                'id'             => 'h6-font-size',
                'type'           => 'typography',
                'title'          => esc_html__( 'H6 Font Size', 'fluent' ),
                'google'         => true,
                'font-weight'    => false,
                'font-style'     => false,
                'font-family'    => false,
                'letter-spacing' => false,
                'text-align'     => false,
                'line-height'    => false,
                'text-transform' => false,
                'color'          => false,
				'subsets'	     => false,
                'default'        => array(
                    'font-size' => '16'
                )
            ),
            array(
                'id'       => 'section-heading-font-end',
                'type'     => 'section',
                'indent'   => true,
            ),

        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Color Scheme', 'fluent' ),
        'id'     => 'color-scheme',
        'icon'   => 'el el-brush',
        'fields' => array(
            array(
				'id'          => 'primary-color',
				'type'        => 'color',
				'title'       => esc_html__('Primary Color', 'fluent'),
				'default'     => '#0E0E0E'
			),
            array(
                'id'       => 'section-topbar-style-start',
                'type'     => 'section',
                'title'    => esc_html__( 'Top Bar', 'fluent' ),
                'indent'   => true,
            ),
            array(
                'id'      => 'topbar-background',
                'type'    => 'color',
                'title'   => esc_html__('Background', 'fluent'),
                'default' => ''
            ),
            array(
                'id'      => 'topbar-border',
                'type'    => 'color',
                'title'   => esc_html__('Border', 'fluent'),
                'default' => '#DADADA'
            ),
            array(
                'id'       => 'topbar-color',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Color', 'fluent' ),
                'options'  => array(
                    'light' => esc_html__('Light', 'fluent'),
                    'dark'  => esc_html__('Dark', 'fluent'),
                ),
                'default'  => 'dark'
            ),
            array(
                'id'       => 'section-topbar-style-end',
                'type'     => 'section',
                'indent'   => true,
            ),
            //end topbar style
            array(
                'id'     => 'section-header-style-start',
                'title'  => esc_html__( 'Header', 'fluent' ),
                'type'   => 'section',
                'indent' => true,
            ),
            array(
                'id'      => 'header-background',
                'type'    => 'color',
                'title'   => esc_html__( 'Background', 'fluent' ),
                'default' => '',
            ),
            array(
                'id'      => 'header-color',
                'type'    => 'color',
                'title'   => esc_html__( 'Color', 'fluent' ),
            ),
            array(
                'id'      => 'header-icon-style',
                'type'    => 'select',
                'title'   => esc_html__( 'Header Icon Style', 'fluent' ),
                'options' => array(
                    'inherit' => esc_html__( 'Inherit From Header', 'fluent' ),
                    'white'   => esc_html__( 'White Icon', 'fluent' ),
                    'black'   => esc_html__( 'Black Icon', 'fluent' )
                ),
                'default' => 'inherit'
            ),
            array(
                'id'     => 'section-header-style-end',
                'type'   => 'section',
                'indent' => true,
            ),
            //end header style
            array(
                'id'     => 'section-footer-style-start',
                'title'  => esc_html__( 'Footer', 'fluent' ),
                'type'   => 'section',
                'indent' => true,
            ),
            array(
                'id'      => 'footer-background',
                'type'    => 'background',
                'title'   => esc_html__( 'Background', 'fluent' ),
                'default' => array(
                    'background-image'      => '',
                    'background-color'      => ''
                ),
            ),
            array(
                'id'      => 'footer-color',
                'type'    => 'color',
                'title'   => esc_html__( 'Color', 'fluent' ),
                'default' => '#535353'
            ),
            array(
                'id'      => 'widget-title-color',
                'type'    => 'color',
                'title'   => esc_html__( 'Widget Title Color', 'fluent' ),
                'default' => '#0e0e0e'
            ),
            array(
                'id'      => 'footer-border',
                'type'    => 'color',
                'title'   => esc_html__( 'Border', 'fluent' ),
                'default' => '#E6E6E6'
            ),
            array(
                'id'     => 'section-footer-style-end',
                'type'   => 'section',
                'indent' => true,
            ),
            //end Footer style
        )
    ) );

    // START Social Network
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Social Network', 'fluent' ),
        'id'     => 'social',
        'icon'   => 'el el-dribbble',
        'fields' => array(
            array(
                'id'       => 'facebook',
                'type'     => 'text',
                'title'    => esc_html__('Facebook', 'fluent'),
                'default'  => 'https://www.facebook.com/joommasters2015'
            ),
            array(
                'id'       => 'twitter',
                'type'     => 'text',
                'title'    => esc_html__('Twitter', 'fluent'),
                'default'  => 'https://twitter.com/joommasters'
            ),
            array(
                'id'       => 'google-plus',
                'type'     => 'text',
                'title'    => esc_html__('Google Plus', 'fluent'),
                'default'  => 'https://plus.google.com/112014307988388695960'
            ),
            array(
                'id'       => 'instagram',
                'type'     => 'text',
                'title'    => esc_html__('Instagram', 'fluent'),
                'default'  => '#'
            ),
            array(
                'id'       => 'pinterest',
                'type'     => 'text',
                'title'    => esc_html__('Pinterest', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'vimeo',
                'type'     => 'text',
                'title'    => esc_html__('Vimeo', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'youtube',
                'type'     => 'text',
                'title'    => esc_html__('YouTube', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'dribbble',
                'type'     => 'text',
                'title'    => esc_html__('Dribbble', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'tumblr',
                'type'     => 'text',
                'title'    => esc_html__('Tumblr', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'linkedin',
                'type'     => 'text',
                'title'    => esc_html__('LinkedIn', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'flickr',
                'type'     => 'text',
                'title'    => esc_html__('Flickr', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'github',
                'type'     => 'text',
                'title'    => esc_html__('GitHub', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'lastfm',
                'type'     => 'text',
                'title'    => esc_html__('Last.fm', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'paypal',
                'type'     => 'text',
                'title'    => esc_html__('PayPal', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'wordpress',
                'type'     => 'text',
                'title'    => esc_html__('WordPress', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'skype',
                'type'     => 'text',
                'title'    => esc_html__('Skype', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'yahoo',
                'type'     => 'text',
                'title'    => esc_html__('Yahoo', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'reddit',
                'type'     => 'text',
                'title'    => esc_html__('Reddit', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'deviantart',
                'type'     => 'text',
                'title'    => esc_html__('DeviantART', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'steam',
                'type'     => 'text',
                'title'    => esc_html__('Steam', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'foursquare',
                'type'     => 'text',
                'title'    => esc_html__('Foursquare', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'behance',
                'type'     => 'text',
                'title'    => esc_html__('Behance', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'xing',
                'type'     => 'text',
                'title'    => esc_html__('Xing', 'fluent'),
                'default'  => ''
            ),
            array(
                'id'       => 'stumbleupon',
                'type'     => 'text',
                'title'    => esc_html__('StumbleUpon', 'fluent'),
                'default'  => ''
            ),
        )
    ) );

    // Maintenance
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Maintenance Mode', 'fluent' ),
        'id'     => 'maintenance',
        'icon'   => 'el el-time',
        'fields' => array(
            array(
                'id'       => 'maintenance-mode',
                'type'     => 'switch',
                'title'    => esc_html__('Maintenance Mode', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 0,
            ),
            array(
                'id'       => 'section-maintenance-background-start',
                'title'    => esc_html__('Maintenance Background', 'fluent'),
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'      => 'maintenance-background',
                'type'    => 'background',
                'title'   => esc_html__( 'Background', 'fluent' ),
                'background-color'      => false,
                'default' => array(
                    'background-image'      => '',
                    'background-color'      => ''
                ),
            ),
            array(
                'id'       => 'section-maintenance-background-end',
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'       => 'section-maintenance-text-start',
                'title'    => esc_html__('Maintenance Text', 'fluent'),
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'    => 'maintenance-title',
                'type'  => 'text',
                'title' => esc_html__( 'Title', 'fluent' ),
                'default' => 'Comming Soon'
            ),
            array(
                'id'    => 'maintenance-message',
                'type'  => 'textarea',
                'title' => esc_html__( 'Message', 'fluent' ),
                'default' => 'We are working very hard to give you the best experience with this one. You will love Jms Fluent as much as we do. It will morph perfectly on your needs!'
            ),
            array(
                'id'       => 'section-maintenance-text-end',
                'type'     => 'section',
                'indent'   => true,
            ),
            array(
                'id'       => 'maintenance-countdown',
                'type'     => 'switch',
                'title'    => esc_html__('Enable Countdown', 'fluent'),
                'on'       => esc_html__('Enable', 'fluent'),
				'off'      => esc_html__('Disable', 'fluent'),
				'default'  => 0,
            ),
            array(
                'id'       => 'maintenance-date',
                'type'     => 'select',
                'title'    => esc_html__('Date', 'fluent'),
                'options'  => array(
                    '01' => '01',
    				'02' => '02',
    				'03' => '03',
    				'04' => '04',
    				'05' => '05',
    				'06' => '06',
    				'07' => '07',
    				'08' => '08',
    				'09' => '09',
    				'10' => '10',
    				'11' => '11',
    				'12' => '12',
    				'13' => '13',
    				'14' => '14',
    				'15' => '15',
    				'16' => '16',
    				'17' => '17',
    				'18' => '18',
    				'19' => '19',
    				'20' => '20',
    				'21' => '21',
    				'22' => '22',
    				'23' => '23',
    				'24' => '24',
    				'25' => '25',
    				'26' => '26',
    				'27' => '27',
    				'28' => '28',
    				'29' => '29',
    				'30' => '30',
    				'31' => '31'
                ),
                'default'  => '15',
                'required' => array( 'maintenance-countdown', '=', 1 )
            ),
            array(
                'id'       => 'maintenance-month',
                'type'     => 'select',
                'title'    => esc_html__('Month', 'fluent'),
                'options'  => array(
                    'January'   => 'January',
    				'Febuary'   => 'Febuary',
    				'March'     => 'March',
    				'April'     => 'April',
    				'May'       => 'May',
    				'June'      => 'June',
    				'July'      => 'July',
    				'August'    => 'August',
    				'September' => 'September',
    				'October'   => 'October',
    				'November'  => 'November',
    				'December'  => 'December'
                ),
                'default'  => 'September',
                'required' => array( 'maintenance-countdown', '=', 1 )
            ),
            array(
                'id'       => 'maintenance-year',
                'type'     => 'select',
                'title'    => esc_html__('Year', 'fluent'),
                'options'  => array(
                    '2017' => '2017',
    				'2018' => '2018',
    				'2019' => '2019',
    				'2020' => '2020'
                ),
                'default'  => '2017',
                'required' => array( 'maintenance-countdown', '=', 1 )
            ),
        )
    ) );
