<?php
if ( ! function_exists( 'fluent_setup' ) ) {
   function fluent_setup() {
	   load_theme_textdomain( 'fluent', get_template_directory() . '/languages' );

	   // Add default posts and comments RSS feed links to head.
	   add_theme_support( 'automatic-feed-links' );
	   add_theme_support( 'title-tag' );
	   add_theme_support( 'post-thumbnails' );
	   add_theme_support( 'woocommerce' );
       add_theme_support( 'custom-background' );
       add_theme_support( 'custom-header' );
       add_theme_support( 'custom-background' );
       // Add theme support for selective refresh for widgets.
       add_theme_support( 'customize-selective-refresh-widgets' );

	    // This theme uses wp_nav_menu() in one location.
	    register_nav_menus( array(
		    'primary-menu'  => esc_html__('Primary Menu', 'fluent'),
		    'footer-menu'   => esc_html__('Footer Menu', 'fluent')
	    ) );

	    /*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	    add_theme_support( 'html5', array(
		   'search-form',
		   'comment-form',
		   'comment-list',
		   'gallery',
		   'caption',
	    ) );

        add_editor_style(); // add the default style

        if ( ! isset( $content_width ) ) $content_width = 900;
    }
    add_action( 'after_setup_theme', 'fluent_setup' );
}

if ( ! function_exists('fluent_toolbar_link_theme_setting') ) {
    function fluent_toolbar_link_theme_setting( $wp_admin_bar ) {
        $args = array(
            'id'     => 'theme_setting',
            'title'  => esc_html__('Fluent Theme Setting', 'fluent'),
            'parent' => 'site-name',
            'href'   => admin_url("admin.php?page=_options"),
            'meta'   => array( 'class' => 'my-toolbar-page' ),
        );
        $wp_admin_bar->add_node( $args );
    }
    add_action( 'admin_bar_menu', 'fluent_toolbar_link_theme_setting', 999 );
}

/*
* [ Remove all style woocommerce. ] - - - - - - - - - - - - - - - - - - - -
*/
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/*
* [ Check variable Theme option ] - - - - - - - - - - - - - - - - - - - -
*/
if ( ! function_exists( 'fluent_get_option' ) ) {
	function fluent_get_option($name, $default = '') {
		global $fluent_option;
		if ( isset($fluent_option[$name]) ) {
			return $fluent_option[$name];
		}
		return $default;
	}
}

/* 	Check WooCommerce is activated
/* --------------------------------------------------------------------- */
if ( ! function_exists( 'fluent_woocommerce_activated' ) ) {
	function fluent_woocommerce_activated() {
		return class_exists( 'woocommerce' ) ? true : false;
	}
}

/*
* [ Register Widget Area. ] - - - - - - - - - - - - - - - - - - - -
*/
if ( ! function_exists( 'fluent_register_sidebars' ) ) {
	function fluent_register_sidebars() {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Primary Sidebar', 'fluent' ),
				'id'            => 'primary-sidebar',
				'description'   => esc_html__( 'The Primary Sidebar', 'fluent' ),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h3 class="widget-title">',
				'after_title'   => '</h3>',
			)
		);

        register_sidebar( array(
    		'name'          => esc_html__( 'Toggle Sidebar', 'fluent' ),
    		'id'            => 'toggle-sidebar',
    		'description'   => esc_html__( 'Add widgets here to appear in toggle sidebar.', 'fluent' ),
    		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    		'after_widget'  => '</aside>',
    		'before_title'  => '<h3 class="widget-title">',
    		'after_title'   => '</h3>',
    	) );

        if ( fluent_woocommerce_activated() ) {
            register_sidebar( array(
        		'name'          => esc_html__( 'WooCommerce Sidebar', 'fluent' ),
        		'id'            => 'shop-page',
        		'description'   => esc_html__( 'Add widgets here to appear in shop page sidebar.', 'fluent' ),
        		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        		'after_widget'  => '</aside>',
        		'before_title'  => '<h3 class="widget-title">',
        		'after_title'   => '</h3>',
        	) );

            register_sidebar( array(
        		'name'          => esc_html__( 'WooCommerce Filter Sidebar', 'fluent' ),
        		'id'            => 'woocommerce-filter-sidebar',
        		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        		'after_widget'  => '</aside>',
        		'before_title'  => '<h3 class="widget-title">',
        		'after_title'   => '</h3>',
        	) );
        }

        $footer_column = fluent_get_option('footer-column', 4);

        if ( isset($footer_column) ) {
            for ( $i = 1, $n = $footer_column; $i <= $n; $i++ ) {
    			register_sidebar(
    				array(
    					'name'          => esc_html__( 'Footer Area #', 'fluent' ) . $i,
    					'id'            => 'footer-' . $i,
    					'description'   => sprintf( esc_html__( 'The #%s column in footer area', 'fluent' ), $i ),
    					'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    					'after_widget'  => '</aside>',
    					'before_title'  => '<h3 class="widget-title">',
    					'after_title'   => '</h3>',
    				)
    			);
    		}
        }
	}
    add_action( 'widgets_init', 'fluent_register_sidebars' );
}

/*
* [ Add a pingback url auto-discovery header for singularly identifiable articles. ] - - - - - - - - - - - - - - - - - - - -
*/
if ( ! function_exists('fluent_pingback_header') ) {
    function fluent_pingback_header() {
    	if ( is_singular() && pings_open() ) {
    		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    	}
    }
    add_action( 'wp_head', 'fluent_pingback_header' );
}

/**
 * ------------------------------------------------------------------------------------------------
 * Enqueue google fonts
 * ------------------------------------------------------------------------------------------------
 */
if( ! function_exists( 'fluent_enqueue_google_fonts' ) ) {
	function fluent_enqueue_google_fonts() {
        $default_google_fonts = 'Raleway:300,400,500,600,700';
        if( ! class_exists('Redux') ) {
            wp_enqueue_style( 'fluent-google-fonts', fluent_get_fonts_url( $default_google_fonts ), array(), '1.0.0' );
        }
	}
    add_action( 'wp_enqueue_scripts', 'fluent_enqueue_google_fonts', 10000 );
}

/**
 * ------------------------------------------------------------------------------------------------
 * Get google fonts URL
 * ------------------------------------------------------------------------------------------------
 */
if( ! function_exists( 'fluent_get_fonts_url') ) {
	function fluent_get_fonts_url( $fonts ) {
	    $font_url = '';
        $font_url = add_query_arg( 'family', urlencode( $fonts ), "//fonts.googleapis.com/css" );

	    return $font_url;
	}
}

/*
* [ Enqueue scripts and styles. ] - - - - - - - - - - - - - - - - - - - -
*/
if ( ! function_exists('fluent_scripts') ) {
    function fluent_scripts() {
        wp_dequeue_style( 'yith-wcwl-font-awesome' );
        // Add custom fonts, used in the main stylesheet.
        wp_enqueue_style( 'bootstrap', FLUENT_URL . '/assets/3rd-party/bootstrap/css/bootstrap.min.css', array(), '3.3.7');
        wp_enqueue_style( 'pe-icon-7-stroke', FLUENT_URL . '/assets/3rd-party/pe-icon-7-stroke/css/pe-icon-7-stroke.css' );
        wp_enqueue_style( 'font-awesome', FLUENT_URL . '/assets/3rd-party/font-awesome/css/font-awesome.min.css' );
        wp_enqueue_style( 'owl-carousel', FLUENT_URL . '/assets/3rd-party/owl-carousel/owl.carousel.min.css' );
        wp_enqueue_style( 'owl-carousel-theme', FLUENT_URL . '/assets/3rd-party/owl-carousel/owl.theme.default.min.css' );
        wp_enqueue_style( 'slick', FLUENT_URL . '/assets/3rd-party/slick/slick.css' );
        wp_enqueue_style( 'magnific-popup', FLUENT_URL . '/assets/3rd-party/magnific-popup/magnific-popup.css' );
        wp_enqueue_style( 'magnific-popup-effect', FLUENT_URL . '/assets/3rd-party/magnific-popup/magnific-popup-effect.css' );

        // Main stylesheet
    	wp_enqueue_style( 'fluent-style', get_stylesheet_uri() );
        wp_add_inline_style( 'fluent-style', fluent_custom_css() );

    	// Load required scripts.
        wp_enqueue_script( 'bootstrap', FLUENT_URL . '/assets/3rd-party/bootstrap/js/bootstrap.min.js', array(), '3.3.7', true);
        wp_enqueue_script( 'imagesloaded', false, array() );
        wp_enqueue_script( 'isotope' , FLUENT_URL . '/assets/3rd-party/isotope/isotope.pkgd.min.js', array(), false, true  );
        wp_enqueue_script( 'owl-carousel', FLUENT_URL . '/assets/3rd-party/owl-carousel/owl.carousel.min.js', array(), '2.2.0', true );
        wp_enqueue_script( 'slick', FLUENT_URL . '/assets/3rd-party/slick/slick.min.js', array(), '1.5.9', true );
    	wp_enqueue_script( 'theia-sticky-sidebar', FLUENT_URL . '/assets/3rd-party/theia-sticky-sidebar/theia-sticky-sidebar.js', array(), false, true );
        wp_enqueue_script( 'magnific-popup' , FLUENT_URL . '/assets/3rd-party/magnific-popup/jquery.magnific-popup.min.js', array(), false, true  );

        // Maintenance mode
        $maintenance_mode = fluent_get_option('maintenance-mode', 1);
        if ( isset($maintenance_mode) && $maintenance_mode == 1 ) {
            wp_enqueue_script( 'countdown' , FLUENT_URL . '/assets/3rd-party/countdown/jquery.countdown.min.js', array(), false, true  );
        }

        // Check if browser smooth scroll is enabled
        $smooth_scroll = fluent_get_option('browser-smooth-scroll', 0);
    	if ( isset($smooth_scroll) && $smooth_scroll == 1 ) {
    		wp_enqueue_script( 'niceScroll', FLUENT_URL . '/assets/3rd-party/nicescroll/jquery.nicescroll.min.js', array(), false, true );
    	}

        // Social sharing in single product
        $sharing = fluent_get_option('wc-single-sharing', 1);
    	if ( function_exists( 'is_product' ) && is_product() && isset($sharing) && $sharing == 1 ) {
    		wp_enqueue_script( 'addthis', '//s7.addthis.com/js/300/addthis_widget.js#pubid=ra-565ea782e30884c0' );
    	}

        if ( class_exists( 'WooCommerce' ) ) {
            wp_enqueue_script( 'wc-add-to-cart-variation' );
            wp_enqueue_script( 'jquery-ui-autocomplete' );
    		wp_enqueue_script('fluent-shop-filter', FLUENT_URL . '/assets/js/shop-filter.js', array(), false, true);
        }

    	// Load theme js
        wp_enqueue_script('fluent-script', FLUENT_URL . '/assets/js/theme.js', array( 'jquery', 'imagesloaded' ), '', true);
        wp_add_inline_script('fluent-script', fluent_custom_javascript(), 'after');

        // Custom localize script
        wp_localize_script( 'fluent-script', 'FL_Data_Js',
            array(
                'ajaxurl'          => esc_url(admin_url( 'admin-ajax.php' )),
                'siteurl'          => get_site_url() . '/index.php',
                'View Wishlist'    => esc_html__( 'View Wishlist', 'fluent' ),
                'viewall_wishlist' => esc_html__( 'View all', 'fluent' ),
                'viewurl_wishlist' => ( class_exists('WC') && class_exists('YITH_WCWL') ) ? YITH_WCWL()->get_wishlist_url('view') : '#',
                'removed_notice'   => esc_html__( '%s has been removed from your cart.', 'fluent' ),
                'load_more'        => esc_html__( 'Load more', 'fluent' ),
                'no_more_item'     => esc_html__( 'All products loaded.', 'fluent' ),
                'days'             => esc_html__( 'days', 'fluent' ),
                'hrs'              => esc_html__( 'hrs', 'fluent' ),
                'mins'             => esc_html__( 'mins', 'fluent' ),
                'secs'             => esc_html__( 'secs', 'fluent' ),
                'permalink'        => ( get_option( 'permalink_structure' ) == '' ) ? 'plain' : '',
            )
        );

        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }

    }
    add_action( 'wp_enqueue_scripts', 'fluent_scripts' );
}

/*  Hook Javascript
/* --------------------------------------------------------------------- */
if ( ! function_exists( 'fluent_custom_javascript' ) ) {
    function fluent_custom_javascript() {
        $smooth_scroll = fluent_get_option('browser-smooth-scroll', 0);

        ob_start();

        /*  Smooth Scroll
        /* --------------------------------------------------------------------- */

        if( isset( $smooth_scroll ) && $smooth_scroll == 1 ) : ?>
            jQuery(document).ready(function($) {
                'use strict';
                $( 'html' ).niceScroll();
            });
        <?php endif;

        ?> var _nonce_fluent = '<?php echo wp_create_nonce( 'bb_fluent' ); ?>';
        <?php

        return ob_get_clean();
    }
}

/*
* [ Add Custom Icon to KingComposer. ] - - - - - - - - - - - - - - - - - - - -
*/

if ( ! function_exists('fluent_add_custom_icon') ) {
    function fluent_add_custom_icon() {
    	if( function_exists( 'kc_add_icon' ) ) {
    		kc_add_icon( FLUENT_URL . '/assets/3rd-party/pe-icon-7-stroke/css/pe-icon-7-stroke.css' );
    	}
    }
    add_action('init', 'fluent_add_custom_icon');
}

/*
* [ Adds custom classes to the array of body classes. ] - - - - - - - - - - - - - - - - - - - -
*/

if ( ! function_exists('fluent_body_class') ) {
    function fluent_body_class( $classes ) {
        $cart_style = fluent_get_option('wc-add-to-cart-style', 'default');

        // Filter Ajax
        $ajax_shop = fluent_get_option( 'wc-filter-ajax', 1);

        if ( isset($_GET['wc-filter-ajax']) && $_GET['wc-filter-ajax'] == 1 ) {
            $ajax_shop = 1;
        }

        if ( isset($ajax_shop) && $ajax_shop == 1 ) {
    		$classes[] = 'fluent-ajax-shop-on';
    	}

        if( $cart_style == 'toggle-sidebar' ) {
        	$classes[] = ' btn-sidebar';
        } elseif( $cart_style == 'toggle-bottom' ) {
        	$classes[] = ' btn-bottom';
        } elseif( $cart_style == 'preview-popup' ) {
        	$classes[] = ' btn-popup';
        } else {
        	$classes[] = ' btn-cart-default';
        }

    	// Adds a class of group-blog to blogs with more than 1 published author.
    	if ( is_multi_author() ) {
    		$classes[] = 'group-blog';
    	}

    	// Adds a class of hfeed to non-singular pages.
    	if ( ! is_singular() ) {
    		$classes[] = 'hfeed';
    	}

        if ( fluent_get_option('sticky-header', 0) == 1 ) {
    		$classes[] = 'has-sticky-header';
    	}

        if ( isset( $_GET['sticky-header'] ) && $_GET['sticky-header'] == 1 ) {
            $classes[] = 'has-sticky-header';
        }

        if ( isset( $_GET['header'] ) && $_GET['header'] == 5 ) {
            $classes[] = 'has-left-header';
        }

    	if ( fluent_get_option('header-layout') == 5 ) {
    		$classes[] = 'has-left-header';
    	}

        $single_ajax_add_to_cart = fluent_get_option('single_ajax_add_to_cart', 1);
        if ( isset($single_ajax_add_to_cart) && $single_ajax_add_to_cart == 1 ) {
    		$classes[] = 'single-product-ajax-add-to-cart-on';
    	}

        // Check if under construction page is enabled
        if ( fluent_get_option('maintenance-mode', 1) ) {
            if ( ! is_user_logged_in() ) {
                $classes[] = 'offline';
            }
    	}

    	return $classes;
    }
    add_filter( 'body_class', 'fluent_body_class' );
}

/**
 * Redirect to under construction page
 */
if ( ! function_exists( 'fluent_offline' ) ) {
	function fluent_offline() {
		$maintenance_mode = fluent_get_option('maintenance-mode', 0);

		// Check if under construction page is enabled
		if ( $maintenance_mode ) {

			if ( ! is_feed() ) {
				// Check if user is not logged in
				if ( ! is_user_logged_in() ) {
					// Load under construction page
					include get_template_directory() . '/maintenance.php';
					exit;
				}
			}

			// Check if user is logged in
			if ( is_user_logged_in() ) {
				global $current_user;

				// Get user role
				wp_get_current_user();

				$loggedInUserID = $current_user->ID;
				$userData = get_userdata( $loggedInUserID );

				// If user role is not 'administrator' then redirect to under construction page
				if ( 'administrator' != $userData->roles[0] ) {
					if ( ! is_feed() ) {
						include get_template_directory() . '/maintenance.php';
						exit;
					}
				}
			}
		}
	}
    add_action( 'template_redirect', 'fluent_offline' );
}

/**
 * Filter portfolio limit per page.
 */

if ( ! function_exists('fluent_portfolio_per_page') ) {
    function fluent_portfolio_per_page( $query ) {
    	if ( ! is_post_type_archive( 'portfolio' ) ) return;

    	// Get portfolio number per page
    	$limit = fluent_get_option( 'portfolio-number-per-page' );
        if ( $query->query_vars['post_type'] == 'portfolio' ) {
            $query->query_vars['posts_per_page'] = $limit;
        }

        return $query;
    }
    add_filter( 'pre_get_posts', 'fluent_portfolio_per_page' );
}

if ( ! function_exists('fluent_script_admin') ) {
    function fluent_script_admin() {
    	wp_enqueue_style( 'fluent-custom-wp-admin', FLUENT_URL . '/assets/css/admin-style.css', false, '1.0.0' );
    }
    add_action('admin_enqueue_scripts', 'fluent_script_admin');
}
