<?php
if ( !class_exists( 'WooCommerce' ) ) return;

if ( ! function_exists('fluent_add_to_cart_message') ) {
	function fluent_add_to_cart_message() {

		if( ! (isset( $_REQUEST['product_id'] ) && (int) $_REQUEST['product_id'] > 0 ) )
			return;

		$titles 	= array();
		$product_id = (int) $_REQUEST['product_id'];

		if ( is_array( $product_id ) ) {
			foreach ( $product_id as $id ) {
				$titles[] = get_the_title( $id );
			}
		} else {
			$titles[] = get_the_title( $product_id );
		}

		$titles     = array_filter( $titles );
		$added_text = sprintf( _n( '<div><b>%s</b> has been added to your cart.</div>', '%s have been added to your cart.', sizeof( $titles ), 'fluent' ), '"' . wc_format_list_of_items( $titles ) . '"' );
		$message    = sprintf( '%s <a href="%s" class="wc-forward db">%s</a>', wp_kses_post( $added_text ), esc_url( wc_get_page_permalink( 'cart' ) ), esc_html__( 'View Cart', 'fluent' ) );
		$data       =  array( 'message' => apply_filters( 'wc_add_to_cart_message', $message, $product_id ) );

		wp_send_json( $data );

		exit();
	}
	add_action( 'wp_ajax_add_to_cart_message', 'fluent_add_to_cart_message' );
	add_action( 'wp_ajax_nopriv_add_to_cart_message', 'fluent_add_to_cart_message' );
}

remove_action( 'woocommerce_before_single_product', 'wc_print_notices', 10 );
remove_action( 'woocommerce_before_shop_loop', 'wc_print_notices', 10 );

/**
 * Customize product quick view.
 */

if ( ! function_exists('fluent_wc_quickview') ) {
	function fluent_wc_quickview() {
		if ( !class_exists( 'WooCommerce' ) ) return;
		// Get product from request.
		if ( isset( $_POST['product'] ) && (int) $_POST['product'] ) {
			global $post, $product, $woocommerce;

			$id      = ( int ) $_POST['product'];
			$post    = get_post( $id );
			$product = get_product( $id );

			if ( $product ) {
				// Get quickview template.
				include FLUENT_PATH . '/woocommerce/content-quickview-product.php';
			}
		}

		exit;
	}
	add_action( 'wp_ajax_fluent_quickview', 'fluent_wc_quickview' );
	add_action( 'wp_ajax_nopriv_fluent_quickview', 'fluent_wc_quickview' );
}

/**
 * Load product tab by category
 */

if ( ! function_exists('fluent_product_tab_by_category') ) {
	function fluent_product_tab_by_category() {
		if ( !class_exists( 'WooCommerce' ) ) return;

		$cat_id      = $_POST['category'];
		$item_class  = $_POST['class'];
		$order       = $_POST['order'];
		$orderby     = $_POST['orderby'];
		$total_items = ( int ) $_POST['total_items'];

		$args = array(
			'post_type'           => 'product',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
			'orderby'             => $orderby,
			'order'               => $order,
			'meta_query'          => WC()->query->get_meta_query(),
			'posts_per_page'      => $total_items,
			'tax_query' 		  => $tax_query
		);

		$tax_query = WC()->query->get_tax_query();

		if ( isset($cat_id) ) {
			$args['tax_query'] = array(
				'relation' => 'AND',
	            array(
	                'taxonomy' => 'product_cat',
	                'field'    => 'id',
	                'terms'    => $cat_id
	            )
			);
		}

	    $products = new WP_Query( apply_filters( 'woocommerce_shortcode_products_query', $args, $atts ) );

		if ( $products->have_posts() ) :
		 	while ( $products->have_posts() ) : $products->the_post(); ?>
	    		<div class="<?php echo esc_attr( $item_class ); ?>">
	                <?php wc_get_template_part( 'content', 'product' ); ?>
	             </div>
			<?php endwhile; // end of the loop. ?>
		<?php endif;
		wp_reset_postdata();

		exit;
	}
	add_action( 'wp_ajax_get_product_by_category', 'fluent_product_tab_by_category' );
	add_action( 'wp_ajax_nopriv_get_product_by_category', 'fluent_product_tab_by_category' );
}

remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 );

if ( ! function_exists('fluent_second_product_thumbnail') ) {
	function fluent_second_product_thumbnail() {
		global $product, $woocommerce, $id;

		$attachment_ids = $product->get_gallery_image_ids();
		$id =	get_post_thumbnail_id( $product->get_id() );

		if ( fluent_get_option('wc-product-hover-style') == 'swap' ) {
			if ( count($attachment_ids) > 0 ) {
				$secondary_image_id = $attachment_ids['0'];
				echo wp_get_attachment_image( $secondary_image_id, 'shop_catalog', '', $attr = array( 'class' => 'secondary-image attachment-shop-catalog' ) );
			}
			else {
				echo wp_get_attachment_image( $id, 'shop_catalog', '', $attr = array( 'class' => 'secondary-image attachment-shop-catalog' ) );
			}
		}
	}
	add_action('woocommerce_before_shop_loop_item_title', 'fluent_second_product_thumbnail', 15);
}

add_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_open', 5);
add_action('woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 4);
add_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 15);
add_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 20);

/**
 * Show the product title in the product loop.
 */
remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
if ( ! function_exists( 'fluent_woocommerce_template_loop_product_title' ) ) {

	/**
	 * Show the product title in the product loop. By default this is an H2.
	 */
	function fluent_woocommerce_template_loop_product_title() {
		echo get_the_title();
	}
	add_action( 'woocommerce_shop_loop_item_title', 'fluent_woocommerce_template_loop_product_title', 10 );
}

add_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_link_open', 5 );
add_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 20 );

// Product Shop
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
add_action( 'fluent_woocommerce_result_count', 'woocommerce_result_count', 5 );

if ( ! function_exists( 'fluent_woocommerce_catalog_ordering' ) ) {
	function fluent_woocommerce_catalog_ordering() {
		global $wp_query;

		if ( 1 === (int) $wp_query->found_posts || ! woocommerce_products_will_display() ) {
			return;
		}

		$orderby                 = isset( $_GET['orderby'] ) ? wc_clean( $_GET['orderby'] ) : apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby' ) );
		$show_default_orderby    = 'menu_order' === apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby' ) );
		$catalog_orderby_options = apply_filters( 'woocommerce_catalog_orderby', array(
			'menu_order' => __( 'Default sorting', 'fluent' ),
			'popularity' => __( 'Popularity', 'fluent' ),
			'rating'     => __( 'Average rating', 'fluent' ),
			'date'       => __( 'Sort by newness', 'fluent' ),
			'price'      => __( 'Price: low to high', 'fluent' ),
			'price-desc' => __( 'Price: high to low', 'fluent' ),
		) );

		if ( ! $show_default_orderby ) {
			unset( $catalog_orderby_options['menu_order'] );
		}

		if ( 'no' === get_option( 'woocommerce_enable_review_rating' ) ) {
			unset( $catalog_orderby_options['rating'] );
		}

		wc_get_template( 'loop/orderby.php', array( 'catalog_orderby_options' => $catalog_orderby_options, 'orderby' => $orderby, 'show_default_orderby' => $show_default_orderby ) );
	}
}

/**
 * ------------------------------------------------------------------------------------------------
 * Addthis sharing hook
 * ------------------------------------------------------------------------------------------------
 */
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50);
if ( !function_exists('fluent_sharing_product') ) {
    function fluent_sharing_product() {
        $sharing = fluent_get_option('wc-single-sharing', 1);

        if ( !isset($sharing) || ! $sharing ) return; ?>

        <div class="addthis_inline_share_toolbox_abpr"></div>
        <?php
    }
	add_action( 'woocommerce_single_product_summary', 'fluent_sharing_product', 50 );
}

remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 7 );


/**
 * Change number of products displayed per page.
 */
if ( ! function_exists('fluent_change_product_per_page') ) {
	function fluent_change_product_per_page() {
		$number = fluent_get_option( 'wc-number-per-page' );
		return $number;
	}
	add_filter( 'loop_shop_per_page', 'fluent_change_product_per_page' );
}

/**
 * Header Account
 */
if ( ! function_exists( 'fluent_my_account' ) ) {
	function fluent_my_account() {
		if ( !class_exists( 'WooCommerce' ) ) return;

		$output = '';
		$output .= '<div class="btn-group compact-hidden">';
		if ( is_user_logged_in() ) {
			$output .= '<a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) . '" class="dropdown-toggle" data-toggle="dropdown">' . esc_html__( 'My Account', 'fluent' ) . '</a>';
		} else {
			$output .= '<a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) . '" class="dropdown-toggle" data-toggle="dropdown">' . esc_html__( 'Login', 'fluent' ) . '</a>';
		}
		$output .='<div class="dropdown-menu">';
			$output .= '<ul>';
				if ( is_user_logged_in() ) {
					$output .= '<li><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) . '">' . esc_html__( 'Dashboard', 'fluent' ) . '</a></li>';
					$output .= '<li><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) . '">' . esc_html__( 'Order Tracking', 'fluent' ) . '</a></li>';
					$output .= '<li><a href="' . esc_url( wc_logout_url( wc_get_page_permalink( 'myaccount' ) ) ) . '">' . esc_html__( 'Logout', 'fluent' ) . '</a></li>';
				} else {
					$output .= '<li><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) . '">' . esc_html__( 'Login / Register', 'fluent' ) . '</a></li>';
				}
			$output .= '</ul>';
		$output .= '</div>';
		$output .= '</div>';

		return apply_filters( 'fluent_my_account', $output );
	}
}



/**
 * Remove product in wishlist.
 */
if ( ! function_exists('fluent_remove_product_wishlist') ) {
	function fluent_remove_product_wishlist() {
		if ( ! ( isset ( $_POST['product_id'] ) && isset( $_POST['_nonce'] ) && wp_verify_nonce( $_POST['_nonce'], 'bb_fluent' ) ) ) {
			wp_send_json ( array(
				'status' => 'false',
				'notice' => __( 'Not validate.', 'fluent' )
			));
		}

		$product_id = intval( $_POST['product_id'] );

		$user_id = get_current_user_id();

		if( $user_id ) {
			global $wpdb;
			$sql = "DELETE FROM {$wpdb->yith_wcwl_items} WHERE user_id = %d AND prod_id = %d";
			$sql_args = array(
				$user_id,
				$product_id
			);
			$wpdb->query( $wpdb->prepare( $sql, $sql_args ) );
		} else {
			$wishlist = yith_getcookie( 'yith_wcwl_products' );
			foreach( $wishlist as $key => $item ){
				if( $item['prod_id'] == $product_id ){
					unset( $wishlist[ $key ] );
				}
			}
			yith_setcookie( 'yith_wcwl_products', $wishlist );
		}
		$data = array(
			'status' => 'true',
		);

		wp_send_json( $data );

		die();
	}
	// Delete product in wishlist
	add_action( 'wp_ajax_fluent_remove_product_wishlist', 'fluent_remove_product_wishlist' );
	add_action( 'wp_ajax_nopriv_fluent_remove_product_wishlist', 'fluent_remove_product_wishlist' );
}

/**
 * Add product title to wishlist notice.
 */
if ( ! function_exists('fluent_add_title_to_wishlist') ) {
	function fluent_add_title_to_wishlist() {
		$product_id = isset( $_POST['add_to_wishlist'] ) ? intval( $_POST['add_to_wishlist'] ) : 0;

		if( ! $product_id ) return;

		$product_title = get_the_title( $product_id );

		return sprintf( __( '<b>%s</b> has been added to your Wishlist', 'fluent' ), $product_title );
	}
	add_filter( 'yith_wcwl_product_added_to_wishlist_message', 'fluent_add_title_to_wishlist' );
}

/* 	Currency Dropdown
/* --------------------------------------------------------------------- */
if ( ! function_exists( 'fluent_currency' )  ) {
 	function fluent_currency() {
		if ( !class_exists( 'WooCommerce' ) ) return;

 		$output = '';

 		$output .= '<div class="btn-group compact-hidden">';
 			$output .= '<a href="javascript:void(0)" class="dropdown-toggle" data-toggle="dropdown">'. esc_html__( 'USD', 'fluent' ) .'</a>';

			$output .= '<div class="dropdown-menu">';
				$output .= '<ul>';
					$output .= '<li><a href="#">'. esc_html__( 'USD', 'fluent' ) .'</a></li>';
					$output .= '<li><a href="#">'. esc_html__( 'Euro', 'fluent' ) .'</a></li>';
				$output .= '</ul>';
			$output .= '</div>';

 		$output .= '</div>';

 		return apply_filters( 'fluent_currency', $output );
 	}
}

/* 	Header cart
/* --------------------------------------------------------------------- */
if ( ! function_exists( 'fluent_header_cart' ) ) {
	function fluent_header_cart(){

		if ( !class_exists( 'WooCommerce' ) ) return;

		global $woocommerce;
		ob_start();
		woocommerce_mini_cart();
		$mini_cart = ob_get_clean();
		//DEMO
		$cart_style = '';
		$cart_style = isset($_GET['ajax_cart']) ? $_GET['ajax_cart'] : fluent_get_option('wc-add-to-cart-style');

    	?>
        <div class="btn-group <?php echo esc_attr($cart_style); ?>" id="header-cart">
            <a href="<?php echo esc_url( wc_get_cart_url() ); ?>" class="dropdown-toggle cart-contents">
                <i class="pe-7s-shopbag"></i>
                <samp class="cart-count pa"><?php echo esc_attr($woocommerce->cart->cart_contents_count);?></samp>
            </a>
            <div class="dropdown-menu shoppingcart-box">
				<div class="widget_shopping_cart_content"><?php echo $mini_cart; ?></div>
            </div>
        </div>
	<?php
	}
}

/**
 * Ensure cart contents update when products are added to the cart via AJAX.
 */

if ( ! function_exists('') ) {
	function fluent_header_cart_fragment( $fragments ) {
		if ( !class_exists( 'WooCommerce' ) ) return;
		global $woocommerce;

		ob_start();
		?>
	    <a href="<?php echo esc_url( wc_get_cart_url() ); ?>" class="dropdown-toggle cart-contents" data-toggle="dropdown">
	        <i class="pe-7s-shopbag"></i>
	        <samp class="cart-count pa"><?php echo esc_attr($woocommerce->cart->cart_contents_count);?></samp>
	    </a>
		<?php
		$fragments['a.cart-contents'] = ob_get_clean();

		return $fragments;

	}
	add_filter('woocommerce_add_to_cart_fragments', 'fluent_header_cart_fragment');
}

/**
 * Load mini cart on header.
 */

if ( ! function_exists('') ) {
	function fluent_render_load_mini_cart() {
		$output = '';

		ob_start();
			$args['list_class'] = '';
			wc_get_template( 'cart/mini-cart.php' );
		$output = ob_get_clean();

		$result = array(
			'message'    => WC()->session->get( 'wc_notices' ),
			'cart_total' => WC()->cart->cart_contents_count,
			'cart_html'  => $output
		);

		echo json_encode( $result );
		exit;
	}
	add_action( 'wp_ajax_load_mini_cart', 'fluent_render_load_mini_cart' );
	add_action( 'wp_ajax_nopriv_load_mini_cart', 'fluent_render_load_mini_cart' );
}

/**
 * Woocommerce Filter
 */
if ( ! function_exists( 'fluent_woocommerce_filter' ) ) {
	function fluent_woocommerce_filter() {
		if ( !class_exists( 'WooCommerce' ) ) return;
		$class_action = '';
		$shop_view_mode 	= isset($_GET['wc-view-mode']) ? (int)$_GET['wc-view-mode'] : fluent_get_option( 'wc-view-mode', 1 );
		$shop_filter 		= isset($_GET['wc-filter']) ? (int)$_GET['wc-filter'] : fluent_get_option( 'wc-filter', 1 );
		$shop_filter_style  = isset($_GET['wc-filter-style']) ? $_GET['wc-filter-style'] : fluent_get_option( 'wc-filter-style', 'filter-off-canvas' );
		$shop_ordering     	= isset($_GET['wc-ordering']) ? (int)$_GET['wc-ordering'] : fluent_get_option( 'wc-ordering', 0 );
		$shop_cat_tab     	= isset($_GET['wc-category-tab']) ? (int)$_GET['wc-category-tab'] : fluent_get_option( 'wc-category-tab', 0 );
		$shop_filter_ajax   = isset($_GET['wc-filter-ajax']) ? (int)$_GET['wc-filter-ajax'] : fluent_get_option( 'wc-filter-ajax', 0 );
		$shop_layout   		= isset($_GET['sidebar']) ? $_GET['sidebar'] : fluent_get_option( 'wc-shop-layout', 'no' );
		if( isset($shop_cat_tab) && $shop_cat_tab == 1 ) $class_action = ' with-category';

		if( (isset($shop_view_mode) && $shop_view_mode != 1 ) && (isset($shop_ordering) && $shop_ordering != 1 ) && ( isset($shop_filter) && $shop_filter != 1 ) && ( isset($shop_cat_tab) && $shop_cat_tab == 1 ) ) {
			$class_action = ' centered-categories';
		}
		?>
		<div class="shop-action">
			<div class="shop-action-inner flex between-xs pb_10<?php echo $class_action; ?>">
				<?php if( $shop_view_mode == 1 ) : ?>
					<div class="wc-switch clearfix hidden-xs">
						<span><?php echo esc_html__('View mode:', 'fluent'); ?></span>
						<a href="javascript:void(0)" class="active view-grid" title="<?php esc_html_e( 'Grid', 'fluent' ); ?>"><i class="icon-grid"></i></a>
						<a href="javascript:void(0)" class="view-list" title="<?php esc_html_e( 'List', 'fluent' ); ?>"><i class="icon-list"></i></a>
					</div>
				<?php endif; ?>
				<?php if ( $shop_cat_tab == 1 && $shop_layout == 'no') : ?>
					<ul id="fl-shop-categories" class="fl-shop-categories">
                        <?php fluent_category_menu(); ?>
                    </ul>
				<?php endif; ?>
				<?php if( (isset($shop_ordering) && $shop_ordering == 1) || (isset($shop_filter) && $shop_filter == 1) ) : ?>
					<div class="action-right">
						<?php if( isset($shop_ordering) && $shop_ordering == 1 ) : ?>
							<?php fluent_woocommerce_catalog_ordering(); ?>
						<?php endif; ?>
						<?php if ( isset($shop_filter) && $shop_filter == 1 && $shop_layout == 'no') : ?>
							<div class="shop-filter-toggle<?php if(isset($shop_filter_style) && $shop_filter_style == 'filter-top' ) { echo ' filter-top'; } else { echo ' filter-off-canvas'; }; ?>">
								<span class="hamburger-box pr">
									<span class="hamburger-inner"></span>
								</span>
								<span class="filter-text"><?php esc_html_e( 'Filter', 'fluent' ); ?></span>
							</div>
						<?php endif; ?>
					</div>
				<?php endif; ?>
			</div>
			<input type="hidden" name="current_url" id="current_url" value="" />
			<?php if ( isset($shop_filter_style) && $shop_filter_style == 'filter-off-canvas' && $shop_layout == 'no') : ?>
				<div class="shop-filter">
					<div class="filter-title flex between-xs">
						<h2 class="dib"><?php esc_html_e('Filter', 'fluent'); ?></h2>
						<span class="pe-7s-close dib close-filter"></span>
					</div>
					<?php if ( is_active_sidebar( 'shop-page' ) ) : ?>
					<div class="shop-filters filter-sidebar clearfix">
						<?php dynamic_sidebar( 'shop-page' ); ?>
					</div>
					<?php endif; ?>
				</div>
			<?php endif; ?>

			<?php if ( isset($shop_filter_style) && $shop_filter_style == 'filter-top' && $shop_layout == 'no') : ?>
				<div class="shop-filter-top">
					<?php if ( is_active_sidebar( 'woocommerce-filter-sidebar' ) ) : ?>
					<div class="shop-filters filter-top clearfix">
						<?php dynamic_sidebar( 'woocommerce-filter-sidebar' ); ?>
					</div>
					<?php endif; ?>
				</div>
			<?php endif; ?>
		</div>
		<?php
	}
}

remove_action( 'woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10 );
if ( ! function_exists( 'fluent_taxonomy_archive_description' ) ) {
	/**
	 * Show an archive description on taxonomy archives.
	 *
	 * @subpackage	Archives
	 */
	function fluent_taxonomy_archive_description() {
		if ( is_product_taxonomy() && 0 === absint( get_query_var( 'paged' ) ) ) {
			$description = wc_format_content( term_description() );
			if ( $description ) {
				echo '<div class="term-description container mt_25">' . $description . '</div>';
			}
		}
	}
	add_action( 'woocommerce_archive_description', 'fluent_taxonomy_archive_description', 10 );
}


if ( ! function_exists('fluent_cart_remove_item') ) {
	function fluent_cart_remove_item() {
	    $item_key = $_POST['item_key'];

        $removed = WC()->cart->remove_cart_item( $item_key ); // Note: WP 2.3 >

        if ( $removed ) {
           $data['status'] = '1';
           $data['cart_count'] = WC()->cart->get_cart_contents_count();
           $data['cart_subtotal'] = WC()->cart->get_cart_subtotal();
        } else {
            $data['status'] = '0';
        }

        echo json_encode( $data );

        exit;
	}
	add_action( 'wp_ajax_cart_remove_item', 'fluent_cart_remove_item' );
	add_action( 'wp_ajax_nopriv_cart_remove_item', 'fluent_cart_remove_item' );
}

add_action( 'fluent_woocommerce_breadcrumb', 'woocommerce_breadcrumb', 10 );

/*
 *	Category menu: Create single category list HTML
 */
if ( ! function_exists( 'fluent_category_menu_create_list' ) ) {
	function fluent_category_menu_create_list( $category, $current_cat_id, $categories_menu_divider, $current_top_cat_id = null ) {
		$output = '<li class="cat-item-' . $category->term_id;

		// Is this the current category?
		if ( $current_cat_id == $category->term_id ) {
			$output .= ' current-cat';
		}
		// Is this the current top parent-category?
		else if ( $current_top_cat_id && $current_top_cat_id == $category->term_id ) {
			$output .= ' current-parent-cat';
		}

		$output .=  '">' . $categories_menu_divider . '<a href="' . esc_url( get_term_link( (int) $category->term_id, 'product_cat' ) ) . '">' . esc_attr( $category->name ) . '</a></li>';

		return $output;
	}
}

/*
 *	Product category menu
 */
if ( ! function_exists( 'fluent_category_menu' ) ) {
	function fluent_category_menu() {
		global $wp_query;

		$shop_cat_tab = fluent_get_option( 'wc-category-tab', 0 );

		$current_cat_id = ( is_tax( 'product_cat' ) ) ? $wp_query->queried_object->term_id : '';
		$is_category = ( strlen( $current_cat_id ) > 0 ) ? true : false;
		$hide_empty = ( $shop_cat_tab == 1 ) ? true : false;

		fluent_category_menu_output( $is_category, $current_cat_id, $hide_empty );
	}
}

/*
 *	Product category menu: Output
 */
if ( ! function_exists( 'fluent_category_menu_output' ) ) {
	function fluent_category_menu_output( $is_category, $current_cat_id, $hide_empty ) {
		global $wp_query;

		//$page_id = wc_get_page_id( 'shop' );
		$page_url = get_permalink( get_page_by_title( 'Shop' ) );
		$hide_sub = true;
		$current_top_cat_id = null;
		$all_categories_class = '';

		// Is this a category page?
		if ( $is_category ) {
			$hide_sub = false;

			// Get current category's top-parent id
			$current_cat_parents = get_ancestors( $current_cat_id, 'product_cat' );
			if ( ! empty( $current_cat_parents ) ) {
				$current_top_cat_id = end( $current_cat_parents ); // Get last item from array
			}

			// Get current category's direct children
			$current_cat_direct_children = get_terms( 'product_cat',
				array(
					'fields'       	=> 'ids',
					'parent'       	=> $current_cat_id,
					'hierarchical'	=> true,
					'hide_empty'   	=> $hide_empty
				)
			);
			$category_has_children = ( empty( $current_cat_direct_children ) ) ? false : true;
		} else {
			// No current category, set "All" as current (if not product tag archive or search)
			if ( ! is_product_tag() && ! isset( $_REQUEST['s'] ) ) {
				$all_categories_class = ' class="current-cat"';
			}
		}

		$output_cat = '<li' . $all_categories_class . '><a href="' . esc_url ( $page_url ) . '">' . esc_html__( 'All', 'fluent' ) . '</a></li>';
		$output_sub_cat = '';
		$output_current_sub_cat = '';

		// Categories order
		$orderby = 'slug';
		$order = 'asc';

		$categories = get_categories( array(
			'type'			=> 'post',
			'orderby'		=> $orderby, // Note: 'name' sorts by product category "menu/sort order"
			'order'			=> $order,
			'hide_empty'	=> $hide_empty,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'product_cat'
		) );

		// Categories menu divider
		$categories_menu_divider = apply_filters( 'fluent_shop_categories_divider', '<span>|</span>' );

		foreach( $categories as $category ) {
			// Is this a sub-category?
			if ( $category->parent != '0' ) {
				// Should sub-categories be included?
				if ( $hide_sub ) {
					continue; // Skip to next loop item
				} else {
					if (
						$category->parent == $current_cat_id || // Include current sub-category's children
						! $category_has_children && $category->parent == $wp_query->queried_object->parent // Include categories with the same parent (if current sub-category doesn't have children)
					) {
						$output_sub_cat .= fluent_category_menu_create_list( $category, $current_cat_id, $categories_menu_divider );
					} else if ($category->term_id == $current_cat_id ) { // Include current sub-category (save in a separate variable so it can be appended to the start of the category list)
						$output_current_sub_cat = fluent_category_menu_create_list( $category, $current_cat_id, $categories_menu_divider );
					}
				}
			} else {
				$output_cat .= fluent_category_menu_create_list( $category, $current_cat_id, $categories_menu_divider, $current_top_cat_id );
			}
		}

		if ( strlen( $output_sub_cat ) > 0 ) {
			$output_sub_cat = '<ul class="fl-shop-sub-categories">' . $output_current_sub_cat . $output_sub_cat . '</ul>';
		}

		$output = $output_cat . $output_sub_cat;

		echo $output;
	}
}
//Redeclare woocommerce function- Show a shop page description on product archives.
if ( ! function_exists( 'woocommerce_product_archive_description' ) ) {
    function woocommerce_product_archive_description() {
		$shop_page_title = '';
		$shop_page_title = isset($_GET['wc-shop-heading']) ? $_GET['wc-shop-heading'] : fluent_get_option('wc-shop-heading');
		if($shop_page_title == 'title_background')
			$shop_page_title = 'Shop';
		elseif($shop_page_title == 'slideshow')
			$shop_page_title = 'Shop - Slideshow';
		//echo $shop_page_title; exit;
		if($shop_page_title == '') return;
	    if ( is_shop() ) {
			$shop_page = get_page_by_title( $shop_page_title );
		    if ( $shop_page ) {
			    $description = wc_format_content( $shop_page->post_content );
			    if ( $description) {
				    echo '<div class="page-description">' . $description . '</div>';
			    }
		    }
	    }
    }
}

// Product countdown
if ( ! function_exists('fluent_product_countdown_timer') ) {
	function fluent_product_countdown_timer() {
		global $post;

		// Sale Countdown
		$sale_price_dates_to = get_post_meta($post->ID, '_sale_price_dates_to', true);

		if ( isset($sale_price_dates_to) && !empty( $sale_price_dates_to ) ) {
			$sale_date  = date('d', $sale_price_dates_to );
			$sale_month = date('m', $sale_price_dates_to );
			$sale_year  = date('Y', $sale_price_dates_to );

			?>
			<div class="fluent-countdown mb_30" data-time='{"day": "<?php echo $sale_date; ?>","month": "<?php echo $sale_month; ?>","year": "<?php echo $sale_year; ?>"}'></div>
			<?php
		}
	}
	add_action( 'woocommerce_single_product_summary', 'fluent_product_countdown_timer', 26 );
}

/**
 * ------------------------------------------------------------------------------------------------
 * AJAX add to cart for all product types
 * ------------------------------------------------------------------------------------------------
 */

if( ! function_exists( 'fluent_ajax_add_to_cart' ) ) {
	function fluent_ajax_add_to_cart() {

		// Get messages
		ob_start();

		wc_print_notices();

		$notices = ob_get_clean();


		// Get mini cart
		ob_start();

		woocommerce_mini_cart();

		$mini_cart = ob_get_clean();

		// Fragments and mini cart are returned
		$data = array(
			'notices' => $notices,
			'fragments' => apply_filters( 'woocommerce_add_to_cart_fragments', array(
					'div.widget_shopping_cart_content' => '<div class="widget_shopping_cart_content">' . $mini_cart . '</div>'
				)
			),
			'cart_hash' => apply_filters( 'woocommerce_add_to_cart_hash', WC()->cart->get_cart_for_session() ? md5( json_encode( WC()->cart->get_cart_for_session() ) ) : '', WC()->cart->get_cart_for_session() )
		);

		wp_send_json( $data );

		die();
	}
	add_action( 'wp_ajax_fluent_ajax_add_to_cart', 'fluent_ajax_add_to_cart' );
	add_action( 'wp_ajax_nopriv_fluent_ajax_add_to_cart', 'fluent_ajax_add_to_cart' );
}
