<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}

// Classes array
$classes = array();

$product_box_style  = fluent_get_option( 'wc-product-style', 'style-1' );
$show_category_name = fluent_get_option( 'wc-category-name', 1 );
$show_wishlist      = fluent_get_option( 'wc-wishlist', 1 );
$show_quickview     = fluent_get_option( 'wc-quick-view', 1 );

// DEMO
if ( isset($_GET['show_quickview']) && ( $_GET['show_quickview'] == 0 ) ) {
	$show_quickview = false;
}

if ( isset($_GET['show_wishlist']) && ( $_GET['show_wishlist'] == 0 ) ) {
	$show_wishlist = false;
}

if ( isset($_GET['show_category_name']) && ( $_GET['show_category_name'] == 0 ) ) {
	$show_category_name = false;
}

if ( isset($_GET['product_box_style']) && ( $_GET['product_box_style'] == 2 ) ) {
	$product_box_style = 'style-2';
}

// Class product box
$productbox_class = '';

if ( fluent_get_option('show-attribute-variation', 1) == 0 ) {
	$productbox_class = ' no-attribute';
}

if ( isset($_GET['ajax_cart']) && ( $_GET['ajax_cart'] == 'no-ajax' ) ) {
	$productbox_class = ' no-ajax';
}


?>

<div <?php post_class('item'); ?>>
	<div class="product-box<?php esc_attr($productbox_class); ?>">
		<div class="product-thumb">
			<?php
			/**
			 * woocommerce_before_shop_loop_item_title hook.
			 *
			 * @hooked woocommerce_template_loop_product_link_open - 5
			 * @hooked woocommerce_show_product_loop_sale_flash - 10
			 * @hooked woocommerce_template_loop_product_thumbnail - 15
			 * @hooked fluent_second_product_thumbnail - 15
			 * @hooked woocommerce_template_loop_product_link_close - 20
			 */
			do_action( 'woocommerce_before_shop_loop_item_title' );

			if ( $show_quickview ) : ?>
				<span class="btn-quickview pa tc dib" data-product="<?php echo esc_attr( $post->ID ); ?>"><i class="pe-7s-link"></i></span>
			<?php endif; ?>

		</div>

		<div class="product-info">
			<?php
			if ( $product_box_style == 'style-1' ) {
				if ( $show_category_name ) {
					echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="product-cat db mb_3"> ', '</span>' );
				}
			} else {
				woocommerce_template_loop_rating();
			}
			?>
			<div class="title-wishlist flex middle-xs between-xs">

				<?php
				do_action( 'woocommerce_shop_loop_item_title' );

				if ( $show_wishlist ) {
					if ( class_exists( 'YITH_WCWL' ) && is_plugin_active( 'yith-woocommerce-wishlist/init.php' ) ) :
						echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
					endif;
				}
				?>

			</div>
			<div class="price-cart pr flex middle-xs">
				<?php
				/**
				 * woocommerce_after_shop_loop_item_title hook.
				 *
				 * @hooked woocommerce_template_loop_price - 10
				 */
				do_action( 'woocommerce_after_shop_loop_item_title' );
				woocommerce_template_loop_add_to_cart();
				?>
			</div>

			<div class="product-extra">
				<?php woocommerce_template_single_excerpt(); ?>
				<?php woocommerce_template_loop_add_to_cart(); ?>
				<?php
				if ( $show_wishlist ) {
					if ( class_exists( 'YITH_WCWL' ) && is_plugin_active( 'yith-woocommerce-wishlist/init.php' ) ) :
						echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
					endif;
				}
				?>
			</div>

		</div>
	</div>
</div>
